/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadarc.h                                           *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADARC_H
#define CAD__ENGINE__CADARC_H

#include "cadentity.h"
#include "cadvector.h"

namespace cad
{
	namespace engine
	{
		class CADVector;
		
		/**
		 * CADArc represents a geometrical arc
		 * @author Christoph Permes
		 */
		class CADArc : public CADEntity
		{
		public:
			CADArc();
			CADArc(const CADVector& center, double radius, double startAngle, double endAngle,
				QString layer = "0", CADPen pen = CADPen());
			~CADArc();
			
			/** @return ID_CADARC as entity ID */
			virtual CADEntityType getEntityType() const
			{ return ID_CADARC; }
			/** @return if the entity is valid */
			virtual bool isValid() const { return radius > 0.0; }
			
			CADVector getCenter() const;
			double getCenterX() const;
			double getCenterY() const;
			
			double getRadius() const;
			double getStartAngle() const;
			double getEndAngle() const;
			double getAngle() const;
			double getLength() const;
			CADVector getStartPoint() const;
			CADVector getEndPoint() const;
			
			void setCenter(const CADVector& center);
			void setCenter(double x, double y);
			void setCenterX(double x);
			void setCenterY(double y);
			
			void setRadius(double radius);
			void setStartAngle(double startAngle);
			void setEndAngle(double endAngle);
			
			/**
			 * set the included angle
			 * @param startPointFixed: if true, the angle is added to the
			 * start angle, else the angle is subtracted from the end angle
			 */
			void setAngle(double angle, bool startAngleFixed = true);
			/**
			 * define the arc by 3 points
			 */
			void set3Points(CADVector start, CADVector second, CADVector end);
			/**
			 * define the arc by startpoint, endpoint and included angle
			 */
			void setStartEndPointAngle(CADVector start, CADVector end, double angle);
			/**
			 * define the arc by startpoint, endpoint and radius
			 */
			void setStartEndPointRadius(CADVector start, CADVector end, double radius);
			
			/** @return the Object "as String" */
			virtual QString toString ();
		
		private:
			CADVector center;
			double radius;
			double startAngle;
			double endAngle;
		
		};
	}
}

#endif // CAD__ENGINE__CADARC_H
