/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadcircle.h                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADCIRCLE_H
#define CAD__ENGINE__CADCIRCLE_H

#include "cadentity.h"
#include "cadvector.h"

namespace cad
{
	namespace engine
	{
		/**
		 * CADCircle represents a geometrical Circle
		 * @author Christoph Permes
		 */
		class CADCircle : public CADEntity
		{
		public:
			CADCircle();
			CADCircle(const CADVector& center, double radius, QString layer = "0", CADPen pen = CADPen());
			~CADCircle();
			
			/** @return ID_CADCIRCLE as entity ID */
			virtual CADEntityType getEntityType() const
			{ return ID_CADCIRCLE; }
			/** @return if the entity is valid */
			virtual bool isValid() const { return radius > 0.0; }
			
			CADVector getCenter() const;
			double getCenterX() const;
			double getCenterY() const;
			
			double getRadius() const;
			double getDiameter() const;
			double getPerimeter() const;
			double getArea() const;
	
			void setCenter(const CADVector& center);
			void setCenter(double x, double y);
			void setCenterX(double x);
			void setCenterY(double y);
			
			void setRadius(double radius);
			
			virtual QString toString();
			
		private:
			CADVector center;
			double radius;
		
		};
	}
}

#endif // CAD__ENGINE__CADCIRCLE_H
