/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadcolor.h                                         *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADCOLOR_H
#define CAD__ENGINE__CADCOLOR_H

namespace cad
{
	namespace engine
	{
		/**
		 * CADColor stores the Colorvalues (0-255) of objects
		 * @author Christoph Permes
		 */
		class CADColor
		{
		public:
			/** Creates a default color (white) */
			CADColor(int value = 7);
			
			~CADColor();
			
			/** @return the value of the color */
			int getValue();
			/** @return the red value of the color */
			int getRed();
			/** @return the green value of the color */
			int getGreen();
			/** @return the blue value of the color */
			int getBlue();
			
			/** set the value of the color */
			void setValue(int value);
			
			/** == operator for CADColor */
			bool operator==(const CADColor& color);
			
			// predefined colors
			static CADColor BYBLOCK;
			static CADColor RED;
			static CADColor YELLOW;
			static CADColor GREEN;
			static CADColor CYAN;
			static CADColor BLUE;
			static CADColor MAGENTA;
			static CADColor WHITE;
			static CADColor BYLAYER;
	
		private:
			//! color value
			int value;
			//! possible 256 colors in RGB
			static const int colors[256][3];
	
		};
	}
}

#endif // CAD__ENGINE__CADCOLOR_H
