/***************************************************************************
 *                                                                         *
 *   include/cad/engine/caddrawing.h                                       *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADDRAWING_H
#define CAD__ENGINE__CADDRAWING_H

#include "cadentitycontainer.h"
#include "cadentity.h"
#include "cadpen.h"
#include "cadlayerlist.h"
#include "cadlinetypelist.h"
#include "../util/layerrenamingmanager.h"

namespace cad
{
	using util::LayerRenamingManager;

	namespace engine
	{
		/**
		 * CADDrawing contains all information about a complete 
		 * drawing and can be saved to a file.
		 * @author Christoph Permes
		 */
		class CADDrawing : public CADEntityContainer
		{
		public:
			CADDrawing();
			virtual ~CADDrawing();
			
			/** @return the drawing name */
			QString getDrawingName() const
			{ return drawingName; }
			/** @return the file name */
			QString getFileName() const
			{ return fileName; }
			/** @return if drawing has been modified */
			bool isModified() const
			{ return modified; }
			/** @return the active pen */
			CADPen getActivePen() const
			{ return activePen; }
			/** @return the layer list */
			CADLayerList getLayerList() const
			{ return layerList; }
			/** @return the linetype list */
			CADLinetypeList getLinetypeList() const
			{ return linetypeList; }
			/** @return the active layer */
			CADLayer getActiveLayer() const;
			
			/** set the drawing name */
			void setDrawingName(QString drawingName)
			{ this->drawingName = drawingName; }
			/** set the file name */
			void setFileName(QString fileName)
			{ this->fileName = fileName; }
			/** set if drawing is modified */
			void setModified(bool modified)
			{ this->modified = modified; }
			/** set the active pen */
			void setActivePen(CADPen pen)
			{ this->activePen = pen; }
			/** set the active layer */
			void setActiveLayer(QString name) throw (Exception);
			
			/** check if any entities are on a layer */
			bool objectsOnLayer(QString layer);
			
			/** update the layer list */
			void updateLayerList(CADLayerList layerList, LayerRenamingManager rm);
			/** update the linetype list */
			void updateLinetypeList(CADLinetypeList linetypeList);
			
		private:
			//! drawing name
			QString drawingName;
			//! file name
			QString fileName;
			//! drawing modified?
			bool modified;
		
			//! active pen
			CADPen activePen;
			//! the layer list
			CADLayerList layerList;
			//! list of available linetypes
			CADLinetypeList linetypeList;
			
		};
	}
}

#endif // CAD__ENGINE__CADDRAWING_H
