/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadellipse.h                                       *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADELLIPSE_H
#define CAD__ENGINE__CADELLIPSE_H

#include "cadentity.h"
#include "cadvector.h"

namespace cad
{
	namespace engine
	{
		/**
		 * CADEllipse represents a geometrical Ellipse
		 * @author Christoph Permes
		 */
		class CADEllipse : public CADEntity
		{
		public:
			CADEllipse();
			CADEllipse(const CADVector& center, const CADVector& majorAxis, double axisRatio, 
				QString layer = "0", CADPen pen = CADPen());
			~CADEllipse();
		
			/** @return ID_CADELLIPSE as entity ID */
			virtual CADEntityType getEntityType() const
			{ return ID_CADELLIPSE; }
			/** @return if the entity is valid */
			virtual bool isValid() const;
			
			CADVector getCenter() const;
			CADVector getMajorAxis() const;
			CADVector getMinorAxis() const;
			double getAxisRatio() const;
		
			void setCenter(const CADVector& center);
			void setCenter(double x, double y);
			void setMajorAxis(const CADVector& axis);
			void setMajorAxisLength(double length);
			void setMinorAxisLength(double length);
			void setAxisRatio(double axisRatio);
			
			virtual QString toString();
	
		private:
			CADVector center;
			CADVector majorAxis;
			double axisRatio;
		
		};
	}
}

#endif // CAD__ENGINE__CADELLIPSE_H
