/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadentity.h                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADENTITY_H
#define CAD__ENGINE__CADENTITY_H

#include "cadpen.h"
#include <qstring.h>

namespace cad
{
	namespace engine
	{
		typedef
			enum { ID_CADARC,
				   ID_CADCIRCLE,
				   ID_CADELLIPSE,
				   ID_CADLINE,
				   ID_CADPOINT,
				   ID_CADRAY,
				   ID_CADXLINE
				 } CADEntityType;
		
		/**
		 * CADEntity is the base class of all geometrical figures.
		 * It stores pen and layer.
		 * @author Christoph Permes
		 */
		class CADEntity
		{
		public:
			/** Create a CADEntity with the given layer and pen */
			CADEntity(QString layer = "0", CADPen pen = CADPen());
			/** Destructor */
			virtual ~CADEntity();
		
			/** @return the entity's ID */
			unsigned long int getEntityID() const
			{ return entityID; }
			/** @return the layer name */
			QString getLayer() const
			{ return layer; }
			/** @return the pen */
			CADPen getPen() const
			{ return pen; }
			/** @return the ID of the entity */
			virtual CADEntityType getEntityType() const = 0;
			/** @return if the entity is valid */
			virtual bool isValid() const { return true; }
			
			/** @return the Object "as String" */
			virtual QString toString ()
			{ return "NULL"; }
				
			/** set the layer name */
			void setLayer(QString layer)
			{ this->layer = layer; }
			/** set the pen */
			void setPen(CADPen pen)
			{ this->pen = pen; }
		
		protected:
			QString layer;
			CADPen pen;
			
		private:
			unsigned long int entityID;
			static unsigned long int idCount;
		
		};
	}
}

#endif // CAD__ENGINE__CADENTITY_H
