/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadentitycontainer.h                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADENTITYCONTAINER_H
#define CAD__ENGINE__CADENTITYCONTAINER_H

#include <qvaluelist.h>

namespace cad
{
	namespace engine
	{
		class CADEntity;
		
		/**
		 * CADEntityContainer contains a list of entities
		 * @author Christoph Permes
		 */
		class CADEntityContainer
		{
		public:
			/** Create an empty CADEntityContainer */
			CADEntityContainer();
			/** Destructor */
			virtual ~CADEntityContainer();
			
			/** @return an entity by the index */
			CADEntity* getEntityAt(int index) const;
			/** @return an entity by the ID */
			CADEntity* getEntity(unsigned long int id) const;
			/** add an entity */
			void addEntity(CADEntity* entity);
			/** remove an entity by the given index */
			void removeEntityAt(int index);
			/** remove an entity by the given id */
			void removeEntity(unsigned long int id);
			/** find an entity by the given id */
			int find(unsigned long int id);
			/** get the number of entities */
			int getSize() const
			{ return entities.size(); }
		
		protected:
			QValueList<CADEntity*> entities;
		
		};
	}
}

#endif // CAD__ENGINE__CADENTITYCONTAINER_H
