/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadline.h                                          *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADLINE_H
#define CAD__ENGINE__CADLINE_H

#include "cadentity.h"
#include "cadvector.h"

namespace cad
{
	namespace engine
	{
		/**
		 * CADLine represents a geometrical Line
		 * @author Christoph Permes
		 */
		class CADLine : public CADEntity
		{
		public:
			CADLine();
			CADLine(const CADVector& start, const CADVector& end, QString layer = "0", CADPen pen = CADPen());
			~CADLine();
			
			/** @return ID_CADLINE as entity ID */
			virtual CADEntityType getEntityType() const
			{ return ID_CADLINE; }
			/** @return if the entity is valid */
			virtual bool isValid() const;
			
			CADVector getStart() const;
			double getStartX() const;
			double getStartY() const;
			
			CADVector getEnd() const;
			double getEndX() const;
			double getEndY() const;
			
			double getLength() const;
			double getAngle() const;
			double getDeltaX() const;
			double getDeltaY() const;
			
			void setStart(const CADVector& start);
			void setStart(double x, double y);
			void setStartX(double x);
			void setStartY(double y);
			
			void setEnd(const CADVector& end);
			void setEnd(double x, double y);
			void setEndX(double x);
			void setEndY(double y);
			
			virtual QString toString();
		
		private:
			CADVector start;
			CADVector end;
		
		};
	}
}

#endif // CAD__ENGINE__CADLAYERLIST_H
