/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadlinetype.h                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADLINETYPE_H
#define CAD__ENGINE__CADLINETYPE_H

#include <qstring.h>
#include <qvaluelist.h>

namespace cad
{
	namespace engine
	{
		/**
		 * CADLinetype defines a line pattern
		 * @author Christoph Permes
		 */
		class CADLinetype
		{
		public:
			/**
			 * Create a linetype with the given attributes
			 */
			CADLinetype(QString name = QString::null, 
				QString descriptiveText = QString::null, 
				QValueList<double> elements = QValueList<double>());
			/** Destructor */
			~CADLinetype();
	
			/** @return the linetype name */
			QString getName() const
			{ return name; }
			/** @return the descriptive text */
			QString getDescriptiveText() const
			{ return descriptiveText; }
			/** @return the total pattern length */
			double getTotalLength() const;
			/** @return the linetype elements */
			QValueList<double> getElements() const
			{ return elements; }
			
			/** set the linetype name */
			void setName(QString name)
			{ this->name = name; }
			/** set the descriptive text */
			void setDescriptiveText(QString descriptiveText)
			{ this->descriptiveText = descriptiveText; }
			/** set the linetype elements */
			void setElements(QValueList<double> elements)
			{ this->elements = elements; }
			
			/**
			 * @return true if the linetype has no name, descriptive text and
			 * no elements
			 */
			bool empty();
	
		private:
			//! the linetype name
			QString name;
			//! descriptive text of linetype
			QString descriptiveText;
			//! linetype elements
			QValueList<double> elements;
	
		};
	}
}

#endif // CAD__ENGINE__CADLINETYPE_H
