/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadray.h                                           *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__ENGINE__CADRAY_H
#define CAD__ENGINE__CADRAY_H

#include "cadentity.h"
#include "cadvector.h"

namespace cad
{
	namespace engine
	{
		/**
		 * CADRay represents a geometrical Ray
		 * @author Christoph Permes
		 */
		class CADRay : public CADEntity
		{
		public:
			CADRay();
			CADRay(const CADVector& start, const CADVector& direction, QString layer = "0", CADPen pen = CADPen());
			~CADRay();
			
			/** @return ID_CADRAY as entity ID */
			virtual CADEntityType getEntityType() const
			{ return ID_CADRAY; }
			/** @return if the entity is valid */
			virtual bool isValid() const;
		
			CADVector getStart() const;
			double getStartX() const;
			double getStartY() const;
			
			CADVector getSecond() const;
			double getSecondX() const;
			double getSecondY() const;
			
			CADVector getDirection() const;
			double getDirectionX() const;
			double getDirectionY() const;
			
			void setStart(const CADVector& start);
			void setStart(double x, double y);
			void setStartX(double x);
			void setStartY(double y);
			
			void setSecond(const CADVector& second);
			void setSecond(double x, double y);
			void setSecondX(double x);
			void setSecondY(double y);
			
			void setDirection(const CADVector& direction);
			void setDirection(double x, double y);
			void setDirectionX(double x);
			void setDirectionY(double y);
			
			virtual QString toString();
		
		protected:
			CADVector start;
			CADVector direction;
		
		};
	}
}

#endif // CAD__ENGINE__CADRAY_H
