/***************************************************************************
 *                                                                         *
 *   include/cad/engine/cadvector.h                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__CADVECTOR_H
#define CAD__CADVECTOR_H

#include <qstring.h>

#include "../util/exception.h"

namespace cad
{
	using util::Exception;

	namespace engine
	{
		/**
		 * CADVector represents the x and y data of a coordinate.
		 * @author Christoph Permes
		 */
		class CADVector
		{
		public:
			CADVector(double x = 0.0, double y = 0.0, bool absolute = true);
			~CADVector();
			
			/** @return the x value */
			double getX() const;
			/** @return the y value */
			double getY() const;
			/** @return the vector length */
			double getLength() const;
			/** @return the vector angle */
			double getAngle() const;
			/** @return if the vector is absolute or relative */
			bool isAbsolute() const;
			
			/** set the x and y values */
			void set(double x, double y);
			/** set the polar values */
			void setPolar(double length, double angle);
			/** set the x value */
			void setX(double x);
			/** set the y value */
			void setY(double y);
			/** set the vector absolute or relative */
			void setAbsolute(bool absolute);
			
			CADVector operator+(const CADVector& vector) const;
			CADVector operator-(const CADVector& vector) const;
			CADVector operator*(const double& d);
			double operator*(const CADVector& v);
			CADVector operator/(const double& d);
			CADVector mid(const CADVector& vector);
			CADVector rotateLeft() const;
			CADVector rotateRight() const;
			
			/** parse a vector from a string */
			static CADVector parseString(QString s) throw (Exception);
			
		private:
			double x;
			double y;
			bool absolute;
			
		};
	}
}

#endif // CAD__ENGINE__CADRAY_H
