/***************************************************************************
 *                                                                         *
 *   include/cad/util/layerrenamingmanager.h                               *
 *   (C) 2004 by Bernhard Jantscher                                        *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAD__UTIL__LAYERRENAMINGMANAGER_H
#define CAD__UTIL__LAYERRENAMINGMANAGER_H

#include "layerrenaming.h"
#include <qstring.h>
#include <qvaluelist.h>

using namespace std;

namespace cad
{
	namespace util
	{
		typedef QValueList<LayerRenaming> RenamingVector;	
	
		/**
		 * LayerRenamingManager is an array of layer renamings
		 * @author Bernhard Jantscher
		 */
		class LayerRenamingManager
		{
		public:
			/** Constructor */
			LayerRenamingManager();
			/** Destructor */
			~LayerRenamingManager();
			
			/** @return the vector of renamings */
			RenamingVector getRenamings() const
			{ return renamings; }
			/** @return the renaming at given index */
			LayerRenaming getRenaming(int index) const
			{ return renamings[index]; }
			/** @return the number of renamings */
			int getCount() const { return renamings.size(); }
			
			/**
			 * Add a layer renaming
			 * Call this function everytime a layer is renamed.
			 */
			void add(QString layerold, QString layernew);
			
		protected:
			RenamingVector renamings;
				
		};
	}
}

#endif // CAD__UTIL__LAYERRENAMINGMANAGER_H
