/***************************************************************************
 *                                                                         *
 *   include/concadgui/dialogs/colordialog.h                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef CONCADGUI__DIALOGS__COLORDIALOG_H
#define CONCADGUI__DIALOGS__COLORDIALOG_H

#include <colordialogbase.h>

#include "../../cad/engine/cadcolor.h"
#include "../../cad/util/exception.h"

namespace concadgui
{
	namespace dialogs
	{
		using cad::engine::CADColor;
		using cad::util::Exception;

		/**
		 * ColorDialog is a dialog for selecting a color
		 * @author Christoph Permes
		 */
		class ColorDialog : public ColorDialogBase
		{
		Q_OBJECT
		public:
			/**
			 * Create a ColorDialog with the given color selected
			 * @param layer: if layer is QString::null BYLAYER and BYBLOCK
			 * will be disabled
			 */
			ColorDialog(CADColor color, QString layer, QWidget* parent = 0, const char* name = 0);
			/** Destructor */
			~ColorDialog();
			
			/** @return the selected color */
			CADColor getColor();
			
			/** Converts a color name to the color value */
			static CADColor nameToValue(QString name) throw (Exception);
			/** Converts a color value to the color name */
			static QString valueToName(CADColor color);
			
		private:
			CADColor color;
			QString layer;
		
		private:
			/** update the color display (name, color) */
			void updateColorDisplay();
		
		private slots:
			void onByLayerClick();
			void onByBlockClick();
			void onColorChange(int color);
			void onColorNameReturn();
		};
	}
}

#endif // CONCADGUI__DIALOGS__COLORDIALOG_H
