/***************************************************************************
 *                                                                         *
 *   include/concadgui/dialogs/layerdialog.h                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADGUI__DIALOGS__LAYERDIALOG_H
#define CONCADGUI__DIALOGS__LAYERDIALOG_H

#include <layerdialogbase.h>

#include "../../cad/engine/cadlayerlist.h"
#include "../../cad/util/layerrenamingmanager.h"

namespace concadio
{
	namespace undoredo
	{
		class UndoAbleGroup;
	}
}

namespace concadgui
{
	namespace dialogs
	{
		using cad::engine::CADLayerList;
		using cad::util::LayerRenamingManager;
		using concadio::undoredo::UndoAbleGroup;
	
		/**
		 * LayerDialog is a Dialog for managing layers
		 * @author Christoph Permes
		 */
		class LayerDialog : public LayerDialogBase
		{
		Q_OBJECT
		public:
			/**
			 * Create a LayerDialog which contains the given layerlist
			 */
			LayerDialog(CADLayerList layerList, QWidget* parent = 0, char* name = 0);
			/** Destructor */
			~LayerDialog();
			
			/** @return the layerlist */
			CADLayerList getLayerList();
			/** @return the renaming manager */
			LayerRenamingManager getLayerRenamingManager() const
			{ return rm; }
			/** @return the undo actions */
			UndoAbleGroup* getUndoActions() const
			{ return undo; }
	
		private:
			//! the layerlist
			CADLayerList layerList;
			//! the layer renaming manager
			LayerRenamingManager rm;
			//! undo actions
			UndoAbleGroup* undo;
			
			/** update the layerlist display */
			void updateLayerView();
	
		public slots:
			void onNewClick();
			void onDeleteClick();
			void onSetActiveClick();
			void onRenameClick();
			void onFreezeClick();
			void onThawClick();
			void onLockClick();
			void onUnlockClick();
			void onColorClick();
			void onLinetypeClick();
	
		};
	}
}

#endif // CONCADGUI__DIALOGS__LAYERDIALOG_H
