/***************************************************************************
 *                                                                         *
 *   include/concadgui/dialogs/linetypedialog.h                            *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef CONCADGUI__DIALOGS__LINETYPEDIALOG_H
#define CONCADGUI__DIALOGS__LINETYPEDIALOG_H

#include <linetypedialogbase.h>

#include "../../cad/engine/cadlinetypelist.h"

namespace concadio
{
	namespace undoredo
	{
		class UndoAbleGroup;
	}
}

namespace concadgui
{
	namespace dialogs
	{
		using cad::engine::CADLinetypeList;
		using concadio::undoredo::UndoAbleGroup;
	
		/**
		 * LinetypeDialog is a dialog for selecting a linetype
		 * @author Christoph Permes
		 */
		class LinetypeDialog : public LinetypeDialogBase
		{
		Q_OBJECT
		public:
			/**
			 * Create a linetype dialog for selecting a linetype from the 
			 * given CADLinetypeList
			 * @param allowByLayer: true if linetype can be BYLAYER
			 */
			LinetypeDialog(CADLinetypeList linetypeList, bool allowByLayer, QWidget* parent = 0, const char* name = 0);
			/** Destructor */
			virtual ~LinetypeDialog();
			
			/** @return the selected linetype */
			QString getLinetype() const;
			/** @return the undo actions */
						/** @return the linetype list */
			CADLinetypeList getLinetypeList() const
			{ return linetypeList; }
			UndoAbleGroup* getUndoActions() const
			{ return undo; }
			/** set the selected linetype */
			void setLinetype(QString linetype);
			
		private:
			UndoAbleGroup* undo;
			bool allowByLayer;
			CADLinetypeList linetypeList;
			
			/** updates the linetype View */
			void updateView();
		
		public slots:
			void onOKClick();
			void onLoadClick();
		};
	}
}

#endif // CONCADGUI__DIALOGS__LINETYPEDIALOG_H
