/***************************************************************************
 *                                                                         *
 *   include/concadgui/edit/propertiesedit.h                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADGUI__EDIT__PROPERTIESEDIT_H
#define CONCADGUI__EDIT__PROPERTIESEDIT_H

#include <propertieseditbase.h>

#include "../../cad/engine/cadpen.h"
#include "../../cad/util/exception.h"

namespace concadgui
{
	namespace edit
	{
		using cad::engine::CADPen;
		using cad::util::Exception;
		
		/**
		 * PropertiesEdit is a widget for editing pen and layer settings
		 * @author Christoph Permes
		 */
		class PropertiesEdit : public PropertiesEditBase
		{
		Q_OBJECT
		public:
			/**
			 * Create a PropertiesEdit which edits the given properties
			 */
			PropertiesEdit(QWidget* parent = 0, const char* name = 0);
			/** Destructor */
			~PropertiesEdit();
			
			/** @return the pen */
			CADPen getPen() throw (Exception);
			/** @return the layer */
			QString getLayer() const;
			/** set the properties */
			void set(CADPen pen, QString layer);
			
		private:
			CADPen pen;
			QString layer;
			
			/** updates the display */
			void update();
		
		private slots:
			void onColorClick();
			void onLayerClick();
			void onLinetypeClick();
			void onLinetypeFactorFocus();

		};
	}
}

#endif // CONCADGUI__EDIT__PROPERTIESEDIT_H
