/***************************************************************************
 *                                                                         *
 *   include/concadgui/mainwindow.h                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADGUI__MAINWINDOW_H
#define CONCADGUI__MAINWINDOW_H

#include <qmainwindow.h>
#include "../concadio/iointerface.h"

class QLabel;
class QComboBox;
class QAction;

namespace concadio
{
	class DrawingManager;
}

using namespace concadio;

namespace concadgui
{
	namespace widgets
	{
		class CommandWidget;
		class EntityView;
	}
	
	using namespace concadgui::widgets;
	
	/**
	 * MainWindow is the main window of ConstructCAD
	 * @author Christoph Permes
	 */
	class MainWindow : public QMainWindow, public IOInterface
	{
	Q_OBJECT
	public:
		MainWindow(QWidget* parent = 0, char* name = 0);
		~MainWindow();
		
		virtual QString readInput() throw (Exception);
		virtual void print(QString s);
		virtual void printLine(QString s);
		virtual void draw(CADDrawing* drawing);
		virtual void updatePropertiesDisplay();
		virtual void quitApplication();
		virtual void lock();
		virtual void unlock();
	
		virtual bool getNewDrawing(CADDrawing& drawing);
		virtual bool getLayerChanges(CADLayerList &layerList, LayerRenamingManager &rm,
			UndoAble *&undoAble);
		virtual bool getColor(CADColor& color, QString activeLayer);
		virtual bool getLinetype(QString& linetype, CADLinetypeList& list, 
			bool allowByLayer, UndoAbleGroup *&undoAble);
		virtual bool getActiveProperties();
		virtual CADEntity* getProperties(CADEntity *entity);

	protected:
		void resizeEvent(QResizeEvent* e);

	private:
		QPopupMenu* fileMenu;
		QPopupMenu* editMenu;
		QPopupMenu* toolsMenu;
		QPopupMenu* toolsDrawMenu;
		QPopupMenu* toolsModifyMenu;
		QPopupMenu* toolsSnapMenu;
		QPopupMenu* toolsDimensioningMenu;
		QPopupMenu* toolsZoomMenu;
		QPopupMenu* toolsToolboxesMenu;
		QPopupMenu* helpMenu;
		QLabel* status[1];
		QToolBar* standardToolBar;
		QToolBar* propertiesToolBar;
		QToolBar* drawToolBar;
		QToolBar* modifyToolBar;
		QToolBar* osnapToolBar;
		QToolBar* dimToolBar;
		QToolBar* zoomToolBar;
		QComboBox* layerSelection;
		QComboBox* linetypeSelection;
		
		QWidget* drawing;
		CommandWidget* commandWidget;
		DrawingManager* drawingManager;
		EntityView* entityView;

		QAction* fileNewAction;
		QAction* fileOpenAction;
		QAction* fileSaveAction;
		QAction* fileSaveAsAction;
		QAction* filePlotAction;
		QAction* fileQuitAction;
		QAction* editUndoAction;
		QAction* editRedoAction;
		QAction* editCutAction;
		QAction* editCopyAction;
		QAction* editPasteAction;
		QAction* toolsOptionsAction;
		QAction* toolsEntityViewAction;
		QAction* helpHelpAction;
		QAction* helpAboutAction;
		
		QAction* propertiesLayerAction;
		QAction* propertiesLayerChangeAction;
		QAction* propertiesColorAction;
		QAction* propertiesLinetypeAction;
		QAction* propertiesObjectAction;
		QAction* propertiesPropertiesAction;
		QAction* zoomInAction;
		QAction* zoomOutAction;
		QAction* zoomWindowAction;
		QAction* zoomAllAction;
		QAction* zoomPreviousAction;
		QAction* zoomScaleAction;
		QAction* zoomExtentAction;
		QAction* zoomCenterAction;
		
		QAction* drawLineAction;
		QAction* drawXLineAction;
		QAction* drawRayAction;
		QAction* drawPLineAction;
		QAction* drawMLineAction;
		QAction* drawArcAction;
		QAction* drawArcContinueAction;
		QAction* drawCircleAction;
		QAction* drawRingAction;
		QAction* drawEllipseAction;
		QAction* drawPolygonAction;
		QAction* drawRectangleAction;
		QAction* drawSolidAction;
		QAction* drawPointAction;
		QAction* drawBlockAction;
		QAction* drawBlockInsertAction;
		QAction* drawHatchAction;
		QAction* drawTextAction;
		QAction* drawTextSLAction;

		QAction* modifyMoveAction;
		QAction* modifyCopyAction;
		QAction* modifyOffsetAction;
		QAction* modifyMirrorAction;
		QAction* modifyArrayRectAction;
		QAction* modifyArrayPolarAction;
		QAction* modifyRotateAction;
		QAction* modifyStretchAction;
		QAction* modifyScaleAction;
		QAction* modifyLengthenAction;
		QAction* modifyTrimAction;
		QAction* modifyExtendAction;
		QAction* modifyBreakAction;
		QAction* modifyEditTextAction;
		QAction* modifyHatchEditAction;
		QAction* modifyChamferAction;
		QAction* modifyFilletAction;
		QAction* modifyExplodeAction;
		QAction* modifyEraseAction;
		
		QAction* snapFromPoint;
		QAction* snapEndpoint;
		QAction* snapMidpoint;
		QAction* snapIntersection;
		QAction* snapCenter;
		QAction* snapQuadrant;
		QAction* snapPerpendicular;
		QAction* snapTangent;
		QAction* snapNode;
		QAction* snapBasepoint;
		QAction* snapNearest;
		QAction* snapNon;
		QAction* snapObject;
		QAction* snapCalculator;
		
		QAction* dimLinear;
		QAction* dimAligned;
		QAction* dimRadius;
		QAction* dimDiameter;
		QAction* dimAngular;
		QAction* dimOrdinate;
		QAction* dimOrdinateX;
		QAction* dimOrdinateY;
		QAction* dimBaseline;
		QAction* dimContinue;
		QAction* dimCenter;
		QAction* dimLeader;
		QAction* dimTEdit;
		QAction* dimTERotate;
		QAction* dimTELeft;
		QAction* dimTEHome;
		QAction* dimTERight;
		QAction* dimStyle;
		QAction* dimEdit;
		
		void createMenu();
		void createFileMenu();
		void createEditMenu();
		void createToolsMenu();
		void createToolsDrawMenu();
		void createToolsModifyMenu();
		void createToolsOSnapMenu();
		void createToolsDimMenu();
		void createToolsZoomMenu();
		void createHelpMenu();

		void createStandardToolBar();
		void createPropertiesToolBar();
		void createDrawToolBar();
		void createModifyToolBar();
		void createOSnapToolBar();
		void createDimToolBar();
		void createZoomToolBar();

		void initializeStatusBar();

		void createActions();
		void createFileActions();
		void createEditActions();
		void createToolsActions();
		void createHelpActions();
		void createPropertiesActions();
		void createZoomActions();
		void createDrawActions();
		void createModifyActions();
		void createSnapActions();
		void createDimActions();

	public slots:
		void onFileNew();
		void onFileOpen();
		void onFileSave();
		void onFileSaveAs();
		void onFilePlot();
		void onFileQuit();
		
		void onEditUndo();
		void onEditRedo();
		void onEditCut();
		void onEditCopy();
		void onEditPaste();

		void onToolsOptions();
		void onToolsEntityView();
		
		void onHelpHelp();
		void onHelpAbout();
		
		void onPropertiesLayer();
		void onPropertiesLayerChange(const QString& string);
		void onPropertiesColor();
		void onPropertiesLinetype();
		void onPropertiesLinetypeChange(const QString& string);
		void onPropertiesObject();
		void onPropertiesProperties();
		
		void onZoomIn();
		void onZoomOut();
		void onZoomWindow();
		void onZoomAll();
		void onZoomPrevious();
		void onZoomScale();
		void onZoomExtent();
		void onZoomCenter();
		
		void onDrawLine();
		void onDrawXLine();
		void onDrawRay();
		void onDrawPLine();
		void onDrawMLine();
		void onDrawArc();
		void onDrawArcContinue();
		void onDrawCircle();
		void onDrawRing();
		void onDrawEllipse();
		void onDrawPolygon();
		void onDrawRectangle();
		void onDrawSolid();
		void onDrawPoint();
		void onDrawBlock();
		void onDrawBlockInsert();
		void onDrawHatch();
		void onDrawText();
		void onDrawTextSL();
		
		void onModifyMove();
		void onModifyCopy();
		void onModifyOffset();
		void onModifyMirror();
		void onModifyArrayRect();
		void onModifyArrayPolar();
		void onModifyRotate();
		void onModifyStretch();
		void onModifyScale();
		void onModifyLengthen();
		void onModifyTrim();
		void onModifyExtend();
		void onModifyBreak();
		void onModifyEditText();
		void onModifyHatchEdit();
		void onModifyChamfer();
		void onModifyFillet();
		void onModifyExplode();
		void onModifyErase();
		
		void onSnapFromPoint();
		void onSnapEndpoint();
		void onSnapMidpoint();
		void onSnapIntersection();
		void onSnapCenter();
		void onSnapQuadrant();
		void onSnapPerpendicular();
		void onSnapTangent();
		void onSnapNode();
		void onSnapBasepoint();
		void onSnapNearest();
		void onSnapNon();
		void onSnapObject();
		void onSnapCalculator();
		
		void onDimLinear();
		void onDimAligned();
		void onDimRadius();
		void onDimDiameter();
		void onDimAngular();
		void onDimOrdinate();
		void onDimOrdinateX();
		void onDimOrdinateY();
		void onDimBaseline();
		void onDimContinue();
		void onDimCenter();
		void onDimLeader();
		void onDimTEdit();
		void onDimTERotate();
		void onDimTELeft();
		void onDimTEHome();
		void onDimTERight();
		void onDimStyle();
		void onDimEdit();
		
		void commandInput(QString& command);
		void escape();

	};
}

#endif // CONCADGUI__MAINWINDOW_H
