/***************************************************************************
 *                                                                         *
 *   include/concadio/creators/entitycreator.h                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADIO__CREATORS__ENTITYCREATOR_H
#define CONCADIO__CREATORS__ENTITYCREATOR_H

#include "../../cad/engine/cadvector.h"
#include "../../cad/util/exception.h"
#include "../undoredo/undo.h"

#include <qstringlist.h>

using namespace cad::engine;
using namespace concadio::undoredo;
using cad::util::Exception;

namespace concadio
{
	class DrawingManager;
	class IOInterface;
	
	namespace creators
	{
		/**
		 * EntityCreator is the base class of all entity creators
		 * @author Christoph Permes
		 */
		class EntityCreator
		{
		public:
			/** Constructor */
			EntityCreator(DrawingManager* dm);
			/** Destructor */
			virtual ~EntityCreator();
			
			/** Start the creation process */
			virtual void create(IOInterface* io) = 0;
			/** undo the last creation part */
			virtual void undo(IOInterface* io) = 0;
			/** @return the undo actions of the creation */
			virtual UndoAble* getUndoActions() = 0;
			
		protected:
			DrawingManager* dm;
			
			/**
			 * Read a point or option from the command line
			 * @param options: accept only the given options
			 */
			QString readPointOptionInput(IOInterface* io, QString prompt, 
				QStringList options) throw (Exception);
			/**
			 * Read a point from the command line
			 */
			QString readPointInput(IOInterface* io, QString prompt) throw (Exception);
			/**
			 * Read a numeric value from the command line
			 */
			double readValueInput(IOInterface* io, QString prompt) throw (Exception);
			/**
			 * Read a numeric value from the command line
			 * @param point: if a point is entered the return value is the distance 
			 * between the given point and the entered point
			 */
			double readValueInput(IOInterface* io, QString prompt, CADVector point) throw (Exception);
			/**
			 * Read an angle from the command line
			 * @param def: default value, if no default leave QString::null
			 */
			double readAngleInput(IOInterface* io, QString prompt, 
				QString def = QString::null) throw (Exception);
			/**
			 * Read an angle from the command line or accept a point which includes 
			 * an angle with the given center and start point
			 * @param def: default value, if no default leave QString::null
			 */
			double readAngleInput(IOInterface* io, QString prompt, CADVector center, 
				CADVector start, QString def = QString::null) throw (Exception);
			
		};
	}
}

#endif // CONCADIO__CREATORS__ENTITYCREATOR_H
