/***************************************************************************
 *                                                                         *
 *   include/concadio/drawingmanager.h                                     *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADIO__DRAWINGMANAGER_H
#define CONCADIO__DRAWINGMANAGER_H

#include "commandhistory.h"
#include "../cad/util/exception.h"

namespace cad
{
	namespace engine
	{
		class CADDrawing;
	}
}

namespace concadio
{
	// forward declaration
	class IOInterface;
	namespace undoredo
	{
		class UndoHistory;
	}
	using cad::engine::CADDrawing;
	using cad::util::Exception;
	using undoredo::UndoHistory;
	
	/**
	 * DrawingManager is an interface between the GUI and the drawing
	 * @author Christoph Permes
	 */
	class DrawingManager
	{
	public:
		virtual ~DrawingManager();
	
		static DrawingManager* getInstance();
		
		/** @return the drawing */
		CADDrawing* getDrawing() const;
		/** @return the undo history */
		UndoHistory* getUndoHistory() const;
		
		/** read a drawing from the given file */
		CADDrawing readFile(QString fileName) throw (Exception);
		/** write the given drawing to a file */
		void writeFile(CADDrawing drawing) throw (Exception);
		
		void fileNew(IOInterface* iointerface);
		void fileOpen(IOInterface* iointerface);
		void fileSave(IOInterface* iointerface);
		void fileSaveAs(IOInterface* iointerface);
		void filePlot(IOInterface* iointerface);
		void editUndo(IOInterface* iointerface);
		void editRedo(IOInterface* iointerface);
		void editCut(IOInterface* iointerface);
		void editCopy(IOInterface* iointerface);
		void editPaste(IOInterface* iointerface);
	
		void propertiesLayer(IOInterface* iointerface);
		void propertiesLayerChange(const QString& string, IOInterface* iointerface);
		void propertiesColor(IOInterface* iointerface);
		void propertiesLinetype(IOInterface* iointerface);
		void propertiesLinetypeChange(const QString& string, IOInterface* iointerface);
		void propertiesObject(IOInterface* iointerface);
		void propertiesProperties(IOInterface* iointerface);
	
		void drawLine(IOInterface* iointerface);
		void drawXLine(IOInterface* iointerface);
		void drawRay(IOInterface* iointerface);
		void drawPLine(IOInterface* iointerface);
		void drawMLine(IOInterface* iointerface);
		void drawArc(IOInterface* iointerface);
		void drawArcContinue(IOInterface* iointerface);
		void drawCircle(IOInterface* iointerface);
		void drawRing(IOInterface* iointerface);
		void drawEllipse(IOInterface* iointerface);
		void drawPolygon(IOInterface* iointerface);
		void drawRectangle(IOInterface* iointerface);
		void drawSolid(IOInterface* iointerface);
		void drawPoint(IOInterface* iointerface);
		void drawBlock(IOInterface* iointerface);
		void drawBlockInsert(IOInterface* iointerface);
		void drawHatch(IOInterface* iointerface);
		void drawText(IOInterface* iointerface);
		void drawTextSL(IOInterface* iointerface);
	
		void modifyMove(IOInterface* iointerface);
		void modifyCopy(IOInterface* iointerface);
		void modifyOffset(IOInterface* iointerface);
		void modifyMirror(IOInterface* iointerface);
		void modifyArrayRect(IOInterface* iointerface);
		void modifyArrayPolar(IOInterface* iointerface);
		void modifyRotate(IOInterface* iointerface);
		void modifyStretch(IOInterface* iointerface);
		void modifyScale(IOInterface* iointerface);
		void modifyLengthen(IOInterface* iointerface);
		void modifyTrim(IOInterface* iointerface);
		void modifyExtend(IOInterface* iointerface);
		void modifyBreak(IOInterface* iointerface);
		void modifyEditText(IOInterface* iointerface);
		void modifyHatchEdit(IOInterface* iointerface);
		void modifyChamfer(IOInterface* iointerface);
		void modifyFillet(IOInterface* iointerface);
		void modifyExplode(IOInterface* iointerface);
		void modifyErase(IOInterface* iointerface);
		
	private:
		DrawingManager();
	
		static DrawingManager* instance;
		CADDrawing* drawing;
		UndoHistory* undoHistory;
		
	};
	
}

#endif // CONCADIO__DRAWINGMANAGER_H
