/***************************************************************************
 *                                                                         *
 *   include/concadio/iointerface.h                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADIO__IOINTERFACE_H
#define CONCADIO__IOINTERFACE_H

#include "../cad/util/exception.h"
#include "../cad/engine/cadvector.h"
#include "../cad/engine/cadlayerlist.h"
#include "../cad/engine/cadlinetypelist.h"
#include "../cad/util/layerrenamingmanager.h"
#include "undoredo/undo.h"

namespace cad
{
	namespace engine
	{
		class CADDrawing;
		class CADEntity;
	}
}

namespace concadio
{
	class DrawingManager;
	class CommandHistory;
	
	using namespace cad::engine;
	using namespace cad::util;
	using namespace undoredo;

	typedef
		enum { IO_Ready, IO_Cancelled, IO_Input, IO_Finished } IOState;
	
	/**
	 * IOInterface is an interface between the GUI and the DrawingManager
	 * @author Christoph Permes
	 */
	class IOInterface
	{
	public:
		/** Constructor */
		IOInterface();
		/** Destructor */
		virtual ~IOInterface();
	
		/** @return the drawing manager */
		DrawingManager* getDrawingManager() const;
		/** @return the command history */
		CommandHistory* getCommandHistory() const;
		/** @return the last entered point */
		CADVector getLastPoint() const
		{ return lastPoint; }
		/** @return the IO state */
		IOState getIOState() const;
		/** @return if IO interface is locked */
		bool isLocked() const { return locked; }
		/** set the IO state */
		void setIOState(IOState state);
		/** set the last entered point*/
		void setLastPoint(CADVector point)
		{ lastPoint = point; }
		
		void runCommand(QString command);
		virtual QString readInput() throw (Exception) = 0;
		virtual void print(QString s) = 0;
		virtual void printLine(QString s) = 0;
		virtual void draw(CADDrawing* drawing) = 0;
		virtual void updatePropertiesDisplay() = 0;
		virtual void quitApplication() = 0;
		virtual void lock() { locked = true; }
		virtual void unlock() { locked = false; }
		
		virtual bool getNewDrawing(CADDrawing& drawing) = 0;
		virtual bool getLayerChanges(CADLayerList &layerList, LayerRenamingManager &rm,
			UndoAble *&undoAble) = 0;
		virtual bool getColor(CADColor& color, QString activeLayer) = 0;
		virtual bool getLinetype(QString& linetype, CADLinetypeList& list, 
			bool allowByLayer, UndoAbleGroup *&undoAble) = 0;
		virtual bool getActiveProperties() = 0;
		virtual CADEntity* getProperties(CADEntity *entity) = 0;
		
	protected:
		DrawingManager* drawingManager;
		CommandHistory* commandHistory;
		bool locked;
		IOState state;
		QString lastInput;
		CADVector lastPoint;
		
	};
	
}

#endif // CONCADIO__IOINTERFACE_H
