/***************************************************************************
 *                                                                         *
 *   include/concadio/undoredo/undo.h                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADIO__UNDOREDO__UNDO_H
#define CONCADIO__UNDOREDO__UNDO_H

#include <qvaluelist.h>

namespace concadio
{
	class DrawingManager;
	class IOInterface;
	
	namespace undoredo
	{
		/**
		 * UndoAble is the base class of all undoable classes
		 * @author Christoph Permes
		 */
		class UndoAble
		{
		public:
			UndoAble() { undone = false; }
			virtual ~UndoAble() {}
			
			virtual UndoAble* copy() = 0;
			
			virtual void undo(DrawingManager* dm, IOInterface* io) = 0;
			virtual void redo(DrawingManager* dm, IOInterface* io) = 0;
			
		protected:
			bool undone;
			
		};
		
		/**
		 * UndoAction is the base class of Undo/Redo actions
		 * @author Christoph Permes
		 */
		class UndoAction : public UndoAble
		{
		public:
			UndoAction() {}
			virtual ~UndoAction() {}
			
			virtual UndoAble* copy() = 0;
			
			virtual void undo(DrawingManager* dm, IOInterface* io) = 0;
			virtual void redo(DrawingManager* dm, IOInterface* io) = 0;
			
		};
		
		/**
		 * UndoAbleGroup represents a group of undoable objects
		 * @author Christoph Permes
		 */
		class UndoAbleGroup : public UndoAble
		{
		public:
			UndoAbleGroup();
			UndoAbleGroup(UndoAbleGroup& undoAbleGroup);
			virtual ~UndoAbleGroup();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
			/** add an undoable object to the group */
			void addUndoAble(UndoAble* undoable);
		
		protected:
			QValueList<UndoAble*> undoGroup;
			
		};
		
		class UndoHistory
		{
		public:
			UndoHistory();
			virtual ~UndoHistory();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
			/** add an undoable to the history */
			void addUndoAble(UndoAble* undoable);
			/** @return if an undo action is possible */
			bool undoPossible() { return (undoGroup.size() > 0); }
			/** @return if a redo action is possible */
			bool redoPossible() { return (redoGroup.size() > 0); }
			/** clear the undo history */
			void clear();
			/** convert the UndoHistory to an UndoGroup */
			UndoAbleGroup* toUndoGroup();
			
		protected:
			QValueList<UndoAble*> undoGroup;
			QValueList<UndoAble*> redoGroup;
		
		};
	}
}

#endif // CONCADIO__UNDOREDO__UNDO_H
