/***************************************************************************
 *                                                                         *
 *   include/concadio/undoredo/undolayer.h                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADIO__UNDOREDO__UNDOLAYER_H
#define CONCADIO__UNDOREDO__UNDOLAYER_H

#include "undo.h"

#include "../../cad/engine/cadlayer.h"

namespace concadio
{
	namespace undoredo
	{
		using cad::engine::CADLayer;
	
		/**
		 * UndoActiveLayer is an undo class for the active layer
		 * @author Christoph Permes
		 */
		class UndoActiveLayer : public UndoAction
		{
		public:
			UndoActiveLayer(QString oldLayer, QString newLayer);
			virtual ~UndoActiveLayer();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
		private:
			QString oldLayer;
			QString newLayer;
			
		};
		
		/**
		 * UndoNewLayer is an undo class for new layers
		 * @author Christoph Permes
		 */
		class UndoNewLayer : public UndoAction
		{
		public:
			UndoNewLayer(CADLayer layer);
			virtual ~UndoNewLayer();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
		private:
			CADLayer layer;
			
		};
		
		/**
		 * UndoChangeLayer is an undo class for changed layers
		 * @author Christoph Permes
		 */
		class UndoChangeLayer : public UndoAction
		{
		public:
			UndoChangeLayer(CADLayer oldLayer, CADLayer newLayer);
			virtual ~UndoChangeLayer();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
		private:
			CADLayer oldLayer;
			CADLayer newLayer;
			
		};
		
		/**
		 * UndoDeleteLayer is an undo class for deleted layers
		 * @author Christoph Permes
		 */
		class UndoDeleteLayer : public UndoAction
		{
		public:
			UndoDeleteLayer(CADLayer layer);
			virtual ~UndoDeleteLayer();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
		private:
			CADLayer layer;
			
		};
	}
}

#endif // CONCADIO__UNDOREDO__UNDOLAYER_H
