/***************************************************************************
 *                                                                         *
 *   include/concadio/undoredo/undolinetype.h                              *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONCADIO__UNDOREDO__UNDOLINETYPE_H
#define CONCADIO__UNDOREDO__UNDOLINETYPE_H

#include "undo.h"

#include "../../cad/engine/cadlinetype.h"

namespace concadio
{
	namespace undoredo
	{
		using cad::engine::CADLinetype;
	
		/**
		 * UndoNewLinetype is an undo class for new linetypes
		 * @author Christoph Permes
		 */
		class UndoNewLinetype : public UndoAction
		{
		public:
			UndoNewLinetype(CADLinetype linetype);
			virtual ~UndoNewLinetype();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
		private:
			CADLinetype linetype;
			
		};
		
		/**
		 * UndoChangeLinetype is an undo class for changed linetypes
		 * @author Christoph Permes
		 */
		class UndoChangeLinetype : public UndoAction
		{
		public:
			UndoChangeLinetype(CADLinetype oldLinetype, CADLinetype newLinetype);
			virtual ~UndoChangeLinetype();
			
			virtual UndoAble* copy();
			
			virtual void undo(DrawingManager* dm, IOInterface* io);
			virtual void redo(DrawingManager* dm, IOInterface* io);
			
		private:
			CADLinetype oldLinetype;
			CADLinetype newLinetype;
			
		};
	}
}

#endif // CONCADIO__UNDOREDO__UNDOLINETYPE_H
