/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/cadcircle.cpp                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/cadcircle.h>

#include <cmath>

using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADCircle::CADCircle() : CADEntity("0", CADPen())
{
	radius = 0.0;
}

CADCircle::CADCircle(const CADVector& center, double radius, QString layer, CADPen pen) :
CADEntity(layer, pen)
{
	this->center = center;
	this->radius = radius;
}

CADCircle::~CADCircle()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

CADVector CADCircle::getCenter() const
{
	return center;
}

double CADCircle::getCenterX() const
{
	return center.getX();
}

double CADCircle::getCenterY() const
{
	return center.getY();
}

double CADCircle::getRadius() const
{
	return radius;
}

double CADCircle::getDiameter() const
{
	return 2 * radius;
}

double CADCircle::getPerimeter() const
{
	return 2 * radius * (4*atan(1.0));
}

double CADCircle::getArea() const
{
	return pow(radius, 2) * (4*atan(1.0));
}

void CADCircle::setCenter(const CADVector& center)
{
	this->center = center;
}

void CADCircle::setCenter(double x, double y)
{
	center.set(x, y);
}

void CADCircle::setCenterX(double x)
{
	center.setX(x);
}

void CADCircle::setCenterY(double y)
{
	center.setY(y);
}

void CADCircle::setRadius(double radius)
{
	this->radius = radius;
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

QString CADCircle::toString()
{
	return QString::number(getEntityID())+":CIRCLE:"+QString::number(center.getX())+
		","+QString::number(center.getY())+";"+QString::number(radius);
}

// EOF
