/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/caddrawing.cpp                                     *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/caddrawing.h>

#include <qobject.h>

using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADDrawing::CADDrawing()
{
	// Create default linetypes
	linetypeList.add(CADLinetype("BYLAYER"));
	linetypeList.add(CADLinetype("BYBLOCK"));
	linetypeList.add(CADLinetype("CONTINUOS", "Solid Line"));
}

CADDrawing::~CADDrawing()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

CADLayer CADDrawing::getActiveLayer() const
{
	return layerList.getLayer(layerList.getActive());
}

void CADDrawing::setActiveLayer(QString name) throw (Exception)
{
	layerList.setActive(name);
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/** check if any entities are on a layer */
bool CADDrawing::objectsOnLayer(QString layer)
{
	qDebug(QString::number(getSize()));
	for (int i = 0; i<this->getSize(); i++)
	{
		if (this->getEntityAt(i)->getLayer() == layer)
			return true;
	}
	return false;
}

/** update the layer list */
void CADDrawing::updateLayerList(CADLayerList layerList, LayerRenamingManager rm)
{
	this->layerList = layerList;
	for (int i = 0; i<rm.getCount(); i++)
	{
		for (int j = 0; j<getSize(); j++)
		{
			if (getEntityAt(j)->getLayer() == rm.getRenaming(i).getOldLayer())
				getEntityAt(j)->setLayer(rm.getRenaming(i).getNewLayer());
		}
	}
}

/** update the linetype list */
void CADDrawing::updateLinetypeList(CADLinetypeList linetypeList)
{
	// TODO: check for deleted linetypes
	this->linetypeList = linetypeList;
}

// EOF
