/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/cadellipse.cpp                                     *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/cadellipse.h>

#include <cmath>

using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADEllipse::CADEllipse() : CADEntity("0", CADPen())
{
	center = CADVector(0.0, 0.0);
	majorAxis = CADVector(0.0);
	axisRatio = 0.0;
}

CADEllipse::CADEllipse(const CADVector& center, const CADVector& majorAxis, double axisRatio, 
	QString layer, CADPen pen) : CADEntity(layer, pen)
{
	this->center = center;
	this->majorAxis = majorAxis;
	this->axisRatio = axisRatio;
}

CADEllipse::~CADEllipse()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return if the entity is valid */
bool CADEllipse::isValid() const
{
	if (majorAxis.getLength() > 0)
		return true;
	return false;
}

CADVector CADEllipse::getCenter() const
{
	return center;
}

CADVector CADEllipse::getMajorAxis() const
{
	return majorAxis;
}

CADVector CADEllipse::getMinorAxis() const
{
	return CADVector(-majorAxis.getY(), majorAxis.getX()) * axisRatio;
}

double CADEllipse::getAxisRatio() const
{
	return axisRatio;
}

void CADEllipse::setCenter(double x, double y)
{
	center = CADVector(x, y);
}

void CADEllipse::setCenter(const CADVector& center)
{
	this->center = center;
}

void CADEllipse::setMajorAxis(const CADVector& axis)
{
	this->majorAxis = axis;
}

void CADEllipse::setMajorAxisLength(double length)
{
	majorAxis.setPolar(length, majorAxis.getAngle());
}

void CADEllipse::setMinorAxisLength(double length)
{
	axisRatio = length/majorAxis.getLength();
}

void CADEllipse::setAxisRatio(double axisRatio)
{
	this->axisRatio = axisRatio;
}

QString CADEllipse::toString()
{
	return QString::number(getEntityID())+":ELLIPSE:"+QString::number(center.getX())+
		","+QString::number(center.getY())+";"+QString::number(majorAxis.getX())+
		","+QString::number(majorAxis.getY())+";"+QString::number(axisRatio);
}

// EOF
