/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/cadentitycontainer.cpp                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/cadentitycontainer.h>

#include <cad/engine/cadentity.h>

using cad::engine::CADEntity;
using cad::engine::CADEntityContainer;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create an empty CADEntityContainer
 */
CADEntityContainer::CADEntityContainer()
{

}

/** Destructor */
CADEntityContainer::~CADEntityContainer()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/** @return an entity by the index */
CADEntity* CADEntityContainer::getEntityAt(int index) const
{
	if ((index >= 0) && (index < entities.size()))
	{
		return entities[index];
	}
	return 0;
}

/** @return an entity by the ID */
CADEntity* CADEntityContainer::getEntity(unsigned long int id) const
{
	/*for (int i = 0; i<entities.size(); i++)
	{
		if (entities[i]->getEntityID() == id)
			return entities[i];
	}*/
	QValueList<CADEntity*>::const_iterator i;
	for (i = entities.begin(); i != entities.end(); i++)
	{
		if ((*i)->getEntityID() == id)
			return *i;
	}
	return 0;
}

/** add an entity */
void CADEntityContainer::addEntity(CADEntity* entity)
{
	entities.push_back(entity);
}

/** remove an entity by the given index */
void CADEntityContainer::removeEntityAt(int index)
{
	if ((index >= 0) && (index < entities.size()))
		entities.erase(entities.at(index));
}

/** remove an entity by the given id */
void CADEntityContainer::removeEntity(unsigned long int id)
{
	QValueList<CADEntity*>::iterator i;
	for (i = entities.begin(); i != entities.end(); i++)
	{
		if ((*i)->getEntityID() == id)
		{
			entities.erase(i);
			return;
		}
	}
}

int CADEntityContainer::find(unsigned long int id)
{
	QValueList<CADEntity*>::iterator it;
	int i;
	for (i = 0, it = entities.begin(); it != entities.end(); i++, it++)
	{
		if ((*it)->getEntityID() == id)
			return i;
	}
	return -1;
}

// EOF
