/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/cadline.cpp                                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/cadline.h>

#include <cmath>

using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADLine::CADLine() : CADEntity("0", CADPen())
{

}

CADLine::CADLine(const CADVector& start, const CADVector& end, QString layer, CADPen pen) :
CADEntity(layer, pen), start(start), end(end)
{

}

CADLine::~CADLine()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return if the entity is valid */
bool CADLine::isValid() const
{
	return true;
}

CADVector CADLine::getStart() const
{
	return start;
}

double CADLine::getStartX() const
{
	return start.getX();
}

double CADLine::getStartY() const
{
	return start.getY();
}

CADVector CADLine::getEnd() const
{
	return end;
}

double CADLine::getEndX() const
{
	return end.getX();
}

double CADLine::getEndY() const
{
	return end.getY();
}

double CADLine::getLength() const
{
	return sqrt(pow(getDeltaX(), 2) + pow(getDeltaY(), 2));
}

double CADLine::getAngle() const
{
	if (getDeltaX() == 0.0) return 0.0;
	return atan(getDeltaY()/getDeltaX()) * (180/(4*atan(1.0)));
}

double CADLine::getDeltaX() const
{
	return end.getX() - start.getX();
}

double CADLine::getDeltaY() const
{
	return end.getY() - start.getY();
}

void CADLine::setStart(const CADVector& start)
{
	this->start = start;
}

void CADLine::setStart(double x, double y)
{
	start.set(x, y);
}

void CADLine::setStartX(double x)
{
	start.setX(x);
}

void CADLine::setStartY(double y)
{
	start.setY(y);
}

void CADLine::setEnd(const CADVector& end)
{
	this->end = end;
}

void CADLine::setEnd(double x, double y)
{
	end.set(x, y);
}

void CADLine::setEndX(double x)
{
	end.setX(x);
}

void CADLine::setEndY(double y)
{
	end.setY(y);
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

QString CADLine::toString()
{
	return QString::number(getEntityID())+":LINE:"+QString::number(start.getX())+","+
		QString::number(start.getY())+";"+QString::number(end.getX())+","+QString::number(end.getY());
}

// EOF
