/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/cadpoint.cpp                                       *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/cadpoint.h>

using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADPoint::CADPoint() : CADEntity("0", CADPen())
{

}

CADPoint::CADPoint(const CADVector& point, QString layer, CADPen pen) :
CADEntity(layer, pen), point(point)
{

}

CADPoint::~CADPoint()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return if the entity is valid */
bool CADPoint::isValid() const
{
	return true;
}

CADVector CADPoint::getPoint() const
{
	return point;
}

double CADPoint::getPointX() const
{
	return point.getX();
}

double CADPoint::getPointY() const
{
	return point.getY();
}

void CADPoint::setPoint(const CADVector& point)
{
	this->point = point;
}

void CADPoint::setPoint(double x, double y)
{
	point.set(x, y);
}

void CADPoint::setPointX(double x)
{
	point.setX(x);
}

void CADPoint::setPointY(double y)
{
	point.setY(y);
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

QString CADPoint::toString()
{
	return QString::number(getEntityID())+":POINT:"+QString::number(point.getX())+","+QString::number(point.getY());
}

// EOF
