/***************************************************************************
 *                                                                         *
 *   src/cad/src/engine/cadray.cpp                                         *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/engine/cadray.h>

using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CADRay::CADRay() : CADEntity("0", CADPen())
{

}

CADRay::CADRay(const CADVector& start, const CADVector& direction, QString layer, CADPen pen) :
CADEntity(layer, pen), start(start), direction(direction)
{

}

CADRay::~CADRay()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return if the entity is valid */
bool CADRay::isValid() const
{
	return true;
}

CADVector CADRay::getStart() const
{
	return start;
}

double CADRay::getStartX() const
{
	return start.getX();
}

double CADRay::getStartY() const
{
	return start.getY();
}

CADVector CADRay::getSecond() const
{
	return CADVector(start.getX()+direction.getX(), start.getY()+direction.getY());
}

double CADRay::getSecondX() const
{
	return start.getX()+direction.getX();
}

double CADRay::getSecondY() const
{
	return start.getY()+direction.getY();
}

CADVector CADRay::getDirection() const
{
	return direction;
}

double CADRay::getDirectionX() const
{
	return direction.getX();
}

double CADRay::getDirectionY() const
{
	return direction.getY();
}

void CADRay::setStart(const CADVector& start)
{
	this->start = start;
}

void CADRay::setStart(double x, double y)
{
	start.set(x, y);
}

void CADRay::setStartX(double x)
{
	start.setX(x);
}

void CADRay::setStartY(double y)
{
	start.setY(y);
}

void CADRay::setSecond(const CADVector& second)
{
	direction.set(second.getX()-start.getX(), second.getY()-start.getY());
}

void CADRay::setSecond(double x, double y)
{
	direction.set(x-start.getX(), y-start.getY());
}

void CADRay::setSecondX(double x)
{
	direction.setX(x - start.getX());
}

void CADRay::setSecondY(double y)
{
	direction.setY(y - start.getY());
}

void CADRay::setDirection(const CADVector& direction)
{
	this->direction = direction;
}

void CADRay::setDirection(double x, double y)
{
	direction.set(x, y);
}

void CADRay::setDirectionX(double x)
{
	direction.setX(x);
}

void CADRay::setDirectionY(double y)
{
	direction.setY(y);
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

QString CADRay::toString()
{
	return QString::number(getEntityID())+":RAY:"+QString::number(start.getX())+
		","+QString::number(start.getY())+";"+QString::number(direction.getX())+
		","+QString::number(direction.getY());
}

// EOF
