/***************************************************************************
 *                                                                         *
 *   src/cad/src/xmlexport/xmldrawing.cpp                                  *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/xmlexport/xmldrawing.h>
#include <cad/xmlexport/xmllayerlist.h>
#include <cad/xmlexport/xmllinetypelist.h>
#include <cad/xmlexport/xmlpen.h>
#include <cad/xmlexport/xmlentitycontainer.h>

using namespace cad::xmlexport;
using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
XMLDrawing::XMLDrawing()
{

}

/** Destructor */
XMLDrawing::~XMLDrawing()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/** exports the given CADDrawing to a QDomDocument */
QDomDocument XMLDrawing::xmlExport(CADDrawing drawing)
{
	QDomDocument doc;
	QDomElement element = doc.createElement("drawing");
	doc.appendChild(element);
	
	element.setAttribute("drawingName", drawing.getDrawingName());
	element.appendChild(XMLLayerList::xmlExport(drawing.getLayerList()));
	element.appendChild(XMLLinetypeList::xmlExport(drawing.getLinetypeList()));
	element.appendChild(XMLPen::xmlExport(drawing.getActivePen()));
	element.setAttribute("activeLayer", drawing.getActiveLayer().getName());
	element.appendChild(XMLEntityContainer::xmlExport(&drawing, "mainContainer"));

	return doc;
}

/** imports the given QDomDocument to a CADDrawing */
CADDrawing XMLDrawing::xmlImport(QDomElement element)
{
	CADDrawing drawing;
	drawing.setDrawingName(element.attribute("drawingName"));
	
	QDomNode node = element.namedItem("layerList");
	drawing.updateLayerList(XMLLayerList::xmlImport(node.toElement()), LayerRenamingManager());
	drawing.setActiveLayer(element.attribute("activeLayer"));
	node = element.namedItem("linetypeList");
	drawing.updateLinetypeList(XMLLinetypeList::xmlImport(node.toElement()));
	node = element.namedItem("pen");
	drawing.setActivePen(XMLPen::xmlImport(node.toElement()));
	node = element.namedItem("mainContainer");
	XMLEntityContainer::xmlImport(node.toElement(), &drawing);
	
	return drawing;
}

// EOF
