/***************************************************************************
 *                                                                         *
 *   src/cad/src/xmlexport/xmlentitycontainer.cpp                          *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/xmlexport/xmlentitycontainer.h>
#include <cad/xmlexport/xmlarc.h>
#include <cad/xmlexport/xmlcircle.h>
#include <cad/xmlexport/xmlline.h>
#include <cad/xmlexport/xmlpoint.h>
#include <cad/xmlexport/xmlray.h>
#include <cad/xmlexport/xmlxline.h>
#include <cad/engine/cadentitycontainer.h>
#include <cad/engine/cadarc.h>
#include <cad/engine/cadcircle.h>
#include <cad/engine/cadline.h>
#include <cad/engine/cadpoint.h>
#include <cad/engine/cadray.h>
#include <cad/engine/cadxline.h>

using namespace cad::xmlexport;
using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
XMLEntityContainer::XMLEntityContainer()
{

}

/** Destructor */
XMLEntityContainer::~XMLEntityContainer()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/** exports the given CADEntityContainer to a QDomDocument */
QDomDocument XMLEntityContainer::xmlExport(CADEntityContainer* entityContainer, QString name)
{
	QDomDocument doc;
	QDomElement element = doc.createElement(name);
	doc.appendChild(element);
	
	for (int i = 0; i<entityContainer->getSize(); i++)
	{
		CADEntity* entity = entityContainer->getEntityAt(i);
		switch (entity->getEntityType())
		{
		case ID_CADARC:
			element.appendChild(XMLArc::xmlExport((CADArc*)entity));
			break;
		case ID_CADCIRCLE:
			element.appendChild(XMLCircle::xmlExport((CADCircle*)entity));
			break;
		case ID_CADLINE:
			element.appendChild(XMLLine::xmlExport((CADLine*)entity));
			break;
		case ID_CADPOINT:
			element.appendChild(XMLPoint::xmlExport((CADPoint*)entity));
			break;
		case ID_CADRAY:
			element.appendChild(XMLRay::xmlExport((CADRay*)entity));
			break;
		case ID_CADXLINE:
			element.appendChild(XMLXLine::xmlExport((CADXLine*)entity));
			break;
		default:
			break;
		}
	}
	return doc;
}

/** imports the given QDomDocument to a CADEntityContainer */
void XMLEntityContainer::xmlImport(QDomElement element, CADEntityContainer* entityContainer)
{
	QDomNodeList list = element.childNodes();
	for (int i = 0; i<list.count(); i++)
	{
		QDomNode e = list.item(i);
		if (e.isElement())
		{
			QDomElement element = e.toElement();
			QString entityType = element.tagName();
			if (entityType == "arc")
				entityContainer->addEntity(XMLArc::xmlImport(element));
			else if (entityType == "circle")
				entityContainer->addEntity(XMLCircle::xmlImport(element));
			else if (entityType == "line")
				entityContainer->addEntity(XMLLine::xmlImport(element));
			else if (entityType == "point")
				entityContainer->addEntity(XMLPoint::xmlImport(element));
			else if (entityType == "ray")
				entityContainer->addEntity(XMLRay::xmlImport(element));
			else if (entityType == "xline")
				entityContainer->addEntity(XMLXLine::xmlImport(element));
		}
	}
}

// EOF
