/***************************************************************************
 *                                                                         *
 *   src/cad/src/xmlexport/xmllinetype.cpp                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <cad/xmlexport/xmllinetype.h>

using namespace cad::xmlexport;
using cad::engine::CADLinetype;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
XMLLinetype::XMLLinetype()
{

}

/** Destructor */
XMLLinetype::~XMLLinetype()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/** exports the given CADLinetype to a QDomDocument */
QDomDocument XMLLinetype::xmlExport(CADLinetype linetype)
{
	QDomDocument doc;
	QDomElement element = doc.createElement("linetype");
	doc.appendChild(element);
	
	element.setAttribute("name", linetype.getName());
	element.setAttribute("descriptiveText", linetype.getDescriptiveText());
	
	QValueList<double> elements = linetype.getElements();
	for (int i = 0; i<elements.size(); i++)
	{
		QDomElement e = doc.createElement("element");
		element.appendChild(e);
		e.setAttribute("length", elements[i]);
	}
	return doc;
}

/** imports the given QDomDocument to a CADLinetype */
CADLinetype XMLLinetype::xmlImport(QDomElement element)
{
	CADLinetype linetype;
	linetype.setName(element.attribute("name"));
	linetype.setDescriptiveText(element.attribute("descriptiveText"));
	
	QDomNodeList list = element.childNodes();
	QValueList<double> elements;
	for (int i = 0; i<list.count(); i++)
	{
		QDomNode e = list.item(i);
		if (e.isElement())
		{
			elements.push_back(e.toElement().attribute("length").toDouble());
		}
	}
	
	return linetype;
}

// EOF
