/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/dialogs/layerselectiondialog.cpp                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/dialogs/layerselectiondialog.h>

#include <concadgui/dialogs/colordialog.h>
#include <cad/engine/cadlayer.h>

#include <qlistview.h>
#include <qmessagebox.h>

using concadgui::dialogs::LayerSelectionDialog;
using namespace cad::engine;

/* TRANSLATOR concadgui::dialogs::LayerSelectionDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a layer selection dialog for selecting a layer from 
 * the given CADLayerList
 */
LayerSelectionDialog::LayerSelectionDialog(CADLayerList layerList, QWidget* parent, char* name):
LayerSelectionDialogBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	
	this->layerList = layerList;
	updateLayerView();
}

/** Destructor */
LayerSelectionDialog::~LayerSelectionDialog()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the name of the selected layer */
QString LayerSelectionDialog::getLayer() const
{
	if (layerView->selectedItem() == 0)
		return QString::null;
	return layerView->selectedItem()->text(0);
}

/** set the selected layer */
void LayerSelectionDialog::setLayer(QString name)
{
	for (QListViewItem* i = layerView->firstChild(); i != layerView->lastItem(); i = i->nextSibling())
	{
		if (i->text(0) == name)
		{
			layerView->setSelected(i, true);
			break;
		}
	}
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void LayerSelectionDialog::updateLayerView()
{
	layerView->clear();
	for (int i = 0; i<layerList.getCount(); i++)
	{
		CADLayer layer = layerList.getLayer(i);
		QListViewItem* item = new QListViewItem(layerView, layer.getName(), 
			QString(layer.getFrozen()?"f ":". ") +
			QString(layer.getLocked()?"l ":". "), 
			ColorDialog::valueToName(layer.getPen().getColor().getValue()), 
			layer.getPen().getLinetype());
		layerView->insertItem(item);
	}
	layerView->setSelected(layerView->firstChild(), true);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LayerSelectionDialog::onOKClick()
{
	if (layerView->selectedItem() != 0)
	{
	    accept();
	}
	else
		QMessageBox::information(this, tr("Error"), tr("Please select a Layer."));
}

// EOF
