/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/dialogs/linetypedialog.cpp                          *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#include <concadgui/dialogs/linetypedialog.h>

#include <concadgui/dialogs/linetypeloaddialog.h>
#include <concadio/undoredo/undo.h>
#include <concadio/undoredo/undolinetype.h>

#include <qlistview.h>
#include <qpushbutton.h>
#include <qmessagebox.h>

using namespace cad::engine;
using namespace concadio::undoredo;
using concadgui::dialogs::LinetypeDialog;
using concadgui::dialogs::LinetypeLoadDialog;

/* TRANSLATOR concadgui::dialogs::LinetypeDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a linetype dialog for selecting one from the given 
 * CADLinetypeList
 * @param allowByLayer: true if linetype can be BYLAYER
 */
LinetypeDialog::LinetypeDialog(CADLinetypeList linetypeList, bool allowByLayer, QWidget* parent, const char* name) : LinetypeDialogBase(parent, name)
{
	this->setCaption(tr("Select Linetype"));
	
	load->setText(tr("&Load"));
	connect(load, SIGNAL(clicked()), this, SLOT(onLoadClick()));
	this->adjustSize();
	
	this->linetypeList = linetypeList;
	this->allowByLayer = allowByLayer;
	updateView();
	undo = new UndoAbleGroup;
}

/** Destructor */
LinetypeDialog::~LinetypeDialog()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the selected linetype */
QString LinetypeDialog::getLinetype() const
{
	return linetypeView->selectedItem()->text(0);
}

/** set the selected linetype */
void LinetypeDialog::setLinetype(QString linetype)
{
	QListViewItem* selected = linetypeView->findItem(linetype, 0);
	if (selected != 0)
		selected->setSelected(true);
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void LinetypeDialog::updateView()
{
	linetypeView->clear();
	
	for (int i = linetypeList.getCount()-1; i>=0; i--)
	{
		CADLinetype lt = linetypeList.getLinetype(i);
		if ((!allowByLayer) && ((lt.getName() == "BYLAYER") || (lt.getName() == "BYBLOCK")))
			continue;
		QListViewItem* item = new QListViewItem(linetypeView, lt.getName(), lt.getDescriptiveText());
	}
}

/***************************************************************************
 * Public Slots                                                            *
 ***************************************************************************/

void LinetypeDialog::onOKClick()
{
	if (linetypeView->selectedItem() == 0)
		QMessageBox::warning(this, tr("Error"), tr("No Linetype has been selected."));
	else
		accept();
}

void LinetypeDialog::onLoadClick()
{
	LinetypeLoadDialog dlg(this);
	if (dlg.exec())
	{
		CADLinetypeList loaded = dlg.getLinetypes();
		for (int i = 0; i<loaded.getCount(); i++)
		{
			if (linetypeList.add(loaded.getLinetype(i)) == false)
			{
				if (QMessageBox::question(
					this,
					tr("Replace Linetypes"), 
					tr("Linetype %1 already exists. Replace?").arg("\""+ loaded.getLinetype(i).getName()+ "\""),
					QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)
				{
					UndoChangeLinetype* undoLinetype = new UndoChangeLinetype(linetypeList.getLinetype(loaded.getLinetype(i).getName()), loaded.getLinetype(i));
					linetypeList.add(loaded.getLinetype(i), true);
					undo->addUndoAble(undoLinetype);
				}
			}
			else
			{
				qDebug("add new linetype to undo group");
				undo->addUndoAble(new UndoNewLinetype(loaded.getLinetype(i)));
			}
		}
		
		updateView();
	}
}

// EOF
