/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/dialogs/linetypeloaddialog.cpp                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#include <concadgui/dialogs/linetypeloaddialog.h>

#include <cad/xmlexport/xmllinetypelist.h>

#include <qlistview.h>
#include <qpushbutton.h>
#include <qmessagebox.h>
#include <qapplication.h>
#include <qfile.h>
#include <qfiledialog.h>
#include <qtextstream.h>

using namespace cad::engine;
using cad::xmlexport::XMLLinetypeList;
using cad::util::Exception;
using concadgui::dialogs::LinetypeLoadDialog;

/* TRANSLATOR concadgui::dialogs::LinetypeLoadDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
LinetypeLoadDialog::LinetypeLoadDialog(QWidget* parent, const char* name) : 
LinetypeDialogBase(parent, name)
{
	this->setCaption(tr("Load Linetypes"));

	load->setText(tr("&File"));
	connect(load, SIGNAL(clicked()), this, SLOT(onFileClick()));
	this->adjustSize();
	
	linetypeView->setSelectionMode(QListView::Extended);
	try
	{
		this->linetypeList = loadFromFile(qApp->applicationDirPath() + "/../share/default.clt");
		updateView();
	}
	catch (Exception e)
	{
		QMessageBox::information(this, tr("Error"), e.getError());
	}
}

LinetypeLoadDialog::~LinetypeLoadDialog()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

CADLinetypeList LinetypeLoadDialog::getLinetypes() const
{
	CADLinetypeList loaded;
	
	QListViewItem* selected = linetypeView->firstChild();
	for (int i = 0; selected != 0; i++)
	{
		if (selected->isSelected())
			loaded.add(linetypeList.getLinetype(i));
		selected = selected->nextSibling();
	}
	return loaded;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

/** loads a CADLinetypeList from a file */
CADLinetypeList LinetypeLoadDialog::loadFromFile(QString filename) throw (Exception)
{
	QDomDocument doc;
	QFile file(filename);
	if (!file.open(IO_ReadOnly))
		throw Exception(tr("File %1 doesn\'t exist.").arg(filename));
	doc.setContent(&file);
	file.close();
	XMLLinetypeList x;
	return x.xmlImport(doc.documentElement());
}

void LinetypeLoadDialog::updateView()
{
	linetypeView->clear();
	
	for (int i = linetypeList.getCount()-1; i>=0; i--)
	{
		CADLinetype lt = linetypeList.getLinetype(i);
		if ((!allowByLayer) && ((lt.getName() == "BYLAYER") || (lt.getName() == "BYBLOCK")))
			continue;
		QListViewItem* item = new QListViewItem(linetypeView, lt.getName(), lt.getDescriptiveText());
	}
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LinetypeLoadDialog::onFileClick()
{
	QString path = QFileDialog::getOpenFileName("~/", 
		"ConstructCAD Linetypes (*.clt);;All Files (*)");
	if (!path.isEmpty())
	{
		try
		{
			CADLinetypeList linetypes = loadFromFile(path);
			if (linetypes.getCount() != 0)
			{
				this->linetypeList = linetypes;
				updateView();
			}
			else
				QMessageBox::information(this, tr("Error"), tr("File contains no valid ConstructCAD Linetypes."));
		}
		catch (Exception e)
		{
			QMessageBox::information(this, tr("Error"), e.getError());
		}
	}
}

// EOF
