/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/dialogs/newdialog.cpp                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/dialogs/newdialog.h>

#include <qlineedit.h>
#include <qcheckbox.h>
#include <qfiledialog.h>
#include <qmessagebox.h>

using concadgui::dialogs::NewDialog;

/* TRANSLATOR concadgui::dialogs::NewDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

NewDialog::NewDialog(QWidget* parent, const char* name) : 
NewDialogBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
}

NewDialog::~NewDialog()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the drawing name */
QString NewDialog::getDrawingName() const
{
	return drawingNameEdit->text();
}

/** @return the file name */
QString NewDialog::getFileName() const
{
	return fileNameEdit->text();
}

/** @return the template name */
QString NewDialog::getTemplateName() const
{
	return templateFileEdit->text();
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void NewDialog::onOK()
{
	if (fileNameEdit->text().isEmpty())
	{
		QMessageBox::warning(this, tr("Error"), 
			tr("Please enter a file name."));
	}
	else if ((useTemplate->isChecked()) && (!QFile::exists(templateFileEdit->text())))
	{
		QMessageBox::warning(this, tr("Error"), 
			tr("Template %1 does not exist.").arg(templateFileEdit->text()));
	}
	else
	{
		accept();
	}
}

void NewDialog::onFileName()
{
	QString path = QFileDialog::getSaveFileName("~/", 
		"ConstructCAD Drawings (*.cdw);;All Files (*)");
	if (!path.isEmpty())
	{
		fileNameEdit->setText(path);
	}
}

void NewDialog::onTemplateFile()
{
	QString path = QFileDialog::getOpenFileName("~/", 
		"ConstructCAD Drawings (*.cdw);;All Files (*.*)");
	if (!path.isEmpty())
	{
		templateFileEdit->setText(path);
	}
}

// EOF
