/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/dialogs/propertiesdialog.cpp                        *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/dialogs/propertiesdialog.h>
#include <concadgui/edit/arcedit.h>
#include <concadgui/edit/circleedit.h>
#include <concadgui/edit/ellipseedit.h>
#include <concadgui/edit/lineedit.h>
#include <concadgui/edit/pointedit.h>
#include <concadgui/edit/rayedit.h>

#include <cad/engine/caddrawing.h>
#include <concadio/drawingmanager.h>
#include <concadio/undoredo/undoactivepen.h>
#include <concadio/undoredo/undolayer.h>

#include <qmessagebox.h>
#include <qframe.h>
#include <qlayout.h>

using concadgui::dialogs::PropertiesDialog;
using namespace concadgui::edit;
using namespace cad::engine;
using namespace concadio::undoredo;
using concadio::DrawingManager;

/* TRANSLATOR concadgui::dialogs::PropertiesDialog */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/**
 * Constructor
 * Create a PropertiesDialog
 * @param entitiy: if entity is NULL the dialog would edit the 
 * active pen and layer settings, else the given entity is edited.
 */
PropertiesDialog::PropertiesDialog(CADEntity* entity, QWidget* parent,
	const char *name) : PropertiesDialogBase(parent, name)
{
	if (entity == 0)
	{
		entityEdit = 0;
		this->setCaption(tr("Object Properties"));
		CADDrawing* drawing = DrawingManager::getInstance()->getDrawing();
		properties->set(drawing->getActivePen(), drawing->getActiveLayer().getName());
	}
	else
	{
		QHBoxLayout* h = new QHBoxLayout(entityEditFrame);
		properties->set(entity->getPen(), entity->getLayer());
		switch (entity->getEntityType())
		{
		case ID_CADARC:
			entityEdit = new ArcEdit((CADArc*)entity, entityEditFrame);
			this->setCaption(tr("Modify Arc"));
			break;
		case ID_CADCIRCLE:
			entityEdit = new CircleEdit((CADCircle*)entity, entityEditFrame);
			this->setCaption(tr("Modify Circle"));
			break;
		case ID_CADELLIPSE:
			entityEdit = new EllipseEdit((CADEllipse*)entity, entityEditFrame);
			this->setCaption(tr("Modify Ellipse"));
			break;
		case ID_CADLINE:
			entityEdit = new LineEdit((CADLine*)entity, entityEditFrame);
			this->setCaption(tr("Modify Line"));
			break;
		case ID_CADPOINT:
			entityEdit = new PointEdit((CADPoint*)entity, entityEditFrame);
			this->setCaption(tr("Modify Point"));
			break;
		case ID_CADRAY:
			entityEdit = new RayEdit((CADRay*)entity, entityEditFrame);
			this->setCaption(tr("Modify Ray"));
			break;
		case ID_CADXLINE:
			entityEdit = new RayEdit((CADRay*)entity, entityEditFrame);
			this->setCaption(tr("Modify Construction Line"));
			break;
		}
		h->insertWidget(-1, dynamic_cast<QWidget*>(entityEdit));
		entityEditFrame->adjustSize();
	}
	this->entity = entity;
	this->adjustSize();
	this->setFixedSize(width(), height());
}

/** Destructor */
PropertiesDialog::~PropertiesDialog()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* PropertiesDialog::getEntity()
{
	return entity;
}

/***************************************************************************
 * PropertiesDialog                                                        *
 ***************************************************************************/

void PropertiesDialog::onOKClick()
{
	try
	{
		if (entity == 0)
		{
			CADDrawing* drawing = DrawingManager::getInstance()->getDrawing();
			UndoActivePen* undoPen = new UndoActivePen(drawing->getActivePen(), properties->getPen());
			drawing->setActivePen(properties->getPen());
			UndoActiveLayer* undoLayer = new UndoActiveLayer(drawing->getActiveLayer().getName(), properties->getLayer());
			drawing->setActiveLayer(properties->getLayer());
			UndoAbleGroup* undoGroup = new UndoAbleGroup;
			undoGroup->addUndoAble(undoPen);
			undoGroup->addUndoAble(undoLayer);
			DrawingManager::getInstance()->getUndoHistory()->addUndoAble(undoGroup);
		}
		else
		{
			entity = entityEdit->getEntity();
			entity->setPen(properties->getPen());
			entity->setLayer(properties->getLayer());
		}
		accept();
	}
	catch (Exception e)
	{
		QMessageBox::information(this, tr("Error"), e.getError());
	}
}

void PropertiesDialog::onCancelClick()
{
	reject();
}

// EOF
