/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/edit/arcedit.cpp                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/edit/arcedit.h>

#include <concadgui/edit/coordinateedit.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qvalidator.h>
#include <qmessagebox.h>

#include <cad/engine/cadarc.h>

using namespace concadgui::edit;
using cad::engine::CADArc;

/* TRANSLATOR concadgui::edit::ArcEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

ArcEdit::ArcEdit(CADArc* arc, QWidget* parent, const char* name) :
ArcEditBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	this->arc = arc;
	this->centerEdit->setTitle("Center");
	connect(centerEdit, SIGNAL(specifyPoint()), this, SLOT(onCenterSpecify()));

	radiusEdit->setValidator(new QDoubleValidator(radiusEdit));
	startAngleEdit->setValidator(new QDoubleValidator(startAngleEdit));
	endAngleEdit->setValidator(new QDoubleValidator(endAngleEdit));
	
	update();
}

ArcEdit::~ArcEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* ArcEdit::getEntity() throw (Exception)
{
	qDebug("ArcEdit::getEntity()");
	arc->setCenterX(centerEdit->getX());
	arc->setCenterY(centerEdit->getY());
	arc->setRadius(radiusEdit->text().toDouble());
	arc->setStartAngle(startAngleEdit->text().toDouble());
	arc->setEndAngle(endAngleEdit->text().toDouble());
	return arc;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void ArcEdit::update()
{
	centerEdit->setCoordinate(arc->getCenterX(), arc->getCenterY());
	QString text;
	text.sprintf("%1.4f", arc->getRadius());
	radiusEdit->setText(text);
	text.sprintf("%1.4f", arc->getStartAngle());
	startAngleEdit->setText(text);
	text.sprintf("%1.4f", arc->getEndAngle());
	endAngleEdit->setText(text);
	text.sprintf("%1.4f", arc->getAngle());
	angleDisplay->setText(text);
	text.sprintf("%1.4f", arc->getLength());
	lengthDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void ArcEdit::onCenterChanged(double &x, double &y)
{
	arc->setCenter(x, y);
	update();
}

void ArcEdit::onCenterSpecify()
{

}

void ArcEdit::onRadiusFocus()
{
	arc->setRadius(radiusEdit->text().toDouble());
	update();
}

void ArcEdit::onStartAngleFocus()
{
	arc->setStartAngle(startAngleEdit->text().toDouble());
	update();
}

void ArcEdit::onEndAngleFocus()
{
	arc->setEndAngle(endAngleEdit->text().toDouble());
	update();
}

// EOF
