/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/edit/circleedit.cpp                                 *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/edit/circleedit.h>

#include <qlineedit.h>
#include <qlabel.h>
#include <qmessagebox.h>
#include <qvalidator.h>
#include <concadgui/edit/coordinateedit.h>

#include <cad/engine/cadcircle.h>

using namespace concadgui::edit;
using cad::engine::CADCircle;

/* TRANSLATOR concadgui::edit::CircleEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CircleEdit::CircleEdit(CADCircle* circle, QWidget* parent, const char* name) :
CircleEditBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	this->circle = circle;
	center->setTitle("Center");
	
	radiusEdit->setValidator(new QDoubleValidator(radiusEdit));
	connect(center, SIGNAL(changed(double&,double&)), this,
		SLOT(onCenterChange(double&,double&)));
	connect(center, SIGNAL(specifyPoint()), this, SLOT(onCenterSpecify()));
	update();
}

CircleEdit::~CircleEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* CircleEdit::getEntity() throw (Exception)
{
	circle->setCenterX(center->getX());
	circle->setCenterY(center->getY());
	circle->setRadius(radiusEdit->text().toDouble());
	return circle;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void CircleEdit::update()
{
	center->setCoordinate(circle->getCenterX(), circle->getCenterY());
	QString text;
	text.sprintf("%1.4f", circle->getRadius());
	radiusEdit->setText(text);
	text.sprintf("%1.4f", circle->getDiameter());
	diameterDisplay->setText(text);
	text.sprintf("%1.4f", circle->getPerimeter());
	perimeterDisplay->setText(text);
	text.sprintf("%1.4f", circle->getArea());
	areaDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void CircleEdit::onCenterChange(double &x, double &y)
{
	circle->setCenter(x, y);
	update();
}

void CircleEdit::onCenterSpecify()
{

}

void CircleEdit::onRadiusFocus()
{
	circle->setRadius(radiusEdit->text().toDouble());
	update();
}

// EOF
