/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/edit/coordinateedit.cpp                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/edit/coordinateedit.h>

#include <qgroupbox.h>
#include <qlineedit.h>
#include <qmessagebox.h>
#include <qvalidator.h>

using concadgui::edit::CoordinateEdit;

/* TRANSLATOR concadgui::edit::CoordinateEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CoordinateEdit::CoordinateEdit(QWidget* parent, const char* name) :
	CoordinateEditBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	
	xEdit->setValidator(new QDoubleValidator(xEdit));
	yEdit->setValidator(new QDoubleValidator(yEdit));
}

CoordinateEdit::~CoordinateEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

void CoordinateEdit::setTitle(QString title)
{
	coordinateGroup->setTitle(title);
}

double CoordinateEdit::getX() throw (Exception)
{
	if (xEdit->text() == "")
		throw Exception(tr("Please enter a value for %1.").arg(coordinateGroup->title()));
	xValue = xEdit->text().toDouble();
	return xValue;
}

double CoordinateEdit::getY() throw (Exception)
{
	if (yEdit->text() == "")
		throw Exception(tr("Please enter a value for %1.").arg(coordinateGroup->title()));
	yValue = yEdit->text().toDouble();
	return yValue;
}

void CoordinateEdit::setCoordinate(double x, double y)
{
	xValue = x;
	yValue = y;
	update();
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void CoordinateEdit::update()
{
	QString text;
	text.sprintf("%1.4f", xValue);
	xEdit->setText(text);
	text.sprintf("%1.4f", yValue);
	yEdit->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void CoordinateEdit::onSpecifyClick()
{
	emit specifyPoint();
}

void CoordinateEdit::onXFocus()
{
	try
	{
		getX();
		update();
		emit changed(xValue, yValue);
	}
	catch (Exception e)
	{
	}
}

void CoordinateEdit::onYFocus()
{
	try
	{
		getY();
		update();
		emit changed(xValue, yValue);
	}
	catch (Exception e)
	{
	}
}

// EOF
