/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/edit/ellipseedit.cpp                                *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/edit/ellipseedit.h>

#include <qlabel.h>
#include <qlineedit.h>
#include <qvalidator.h>
#include <qmessagebox.h>
#include <concadgui/edit/coordinateedit.h>

#include <cad/engine/cadellipse.h>

using namespace concadgui::edit;
using cad::engine::CADEllipse;

/* TRANSLATOR concadgui::edit::EllipseEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

EllipseEdit::EllipseEdit(CADEllipse* ellipse, QWidget* parent, const char* name):
EllipseEditBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	this->ellipse = ellipse;
	center->setTitle("Center");
	
	majorAxisEdit->setValidator(new QDoubleValidator(majorAxisEdit));
	minorAxisEdit->setValidator(new QDoubleValidator(minorAxisEdit));
	connect(center, SIGNAL(changed(double&,double&)), this,
		SLOT(onCenterChanged(double&,double&)));
	connect(center, SIGNAL(specifyPoint()), this, SLOT(onCenterSpecify()));
	update();
}

EllipseEdit::~EllipseEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* EllipseEdit::getEntity() throw (Exception)
{
	ellipse->setCenter(center->getX(), center->getY());
	ellipse->setMajorAxisLength(majorAxisEdit->text().toDouble());
	ellipse->setMinorAxisLength(minorAxisEdit->text().toDouble());
	return ellipse;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void EllipseEdit::update()
{
	center->setCoordinate(ellipse->getCenter().getX(), ellipse->getCenter().getY());
	QString text;
	text.sprintf("%1.4f", ellipse->getMajorAxis().getLength());
	majorAxisEdit->setText(text);
	text.sprintf("%1.4f", ellipse->getMinorAxis().getLength());
	minorAxisEdit->setText(text);
	text.sprintf("%1.4f", ellipse->getAxisRatio());
	axisRatioDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMajorAxis().getX());
	majorAxisXDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMajorAxis().getY());
	majorAxisYDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMinorAxis().getX());
	minorAxisXDisplay->setText(text);
	text.sprintf("%1.4f", ellipse->getMinorAxis().getY());
	minorAxisYDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void EllipseEdit::onCenterChanged(double &x, double &y)
{
	ellipse->setCenter(x, y);
	update();
}

void EllipseEdit::onCenterSpecify()
{

}

void EllipseEdit::onMajorAxisFocus()
{
	ellipse->setMajorAxisLength(majorAxisEdit->text().toDouble());
	update();
}

void EllipseEdit::onMinorAxisFocus()
{
	ellipse->setMinorAxisLength(minorAxisEdit->text().toDouble());
	update();
}

// EOF
