/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/edit/lineedit.cpp                                   *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/edit/lineedit.h>

#include <qlabel.h>
#include <qmessagebox.h>
#include <concadgui/edit/coordinateedit.h>
#include <cad/engine/cadline.h>

using namespace concadgui::edit;
using cad::engine::CADLine;

/* TRANSLATOR concadgui::edit::LineEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

LineEdit::LineEdit(CADLine* line, QWidget* parent, const char* name):
	LineEditBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	this->line = line;
	this->start->setTitle("Start Point");
	this->end->setTitle("End Point");

	connect(start, SIGNAL(changed(double&,double&)), this, 
		SLOT(onStartChange(double&,double&)));
	connect(start, SIGNAL(specifyPoint()), this, SLOT(onStartSpecify()));
	connect(end, SIGNAL(changed(double&,double&)), this, 
		SLOT(onEndChange(double&,double&)));
	connect(end, SIGNAL(specifyPoint()), this, SLOT(onEndSpecify()));
	
	update();
}

LineEdit::~LineEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* LineEdit::getEntity() throw (Exception)
{
	line->setStartX(start->getX());
	line->setStartY(start->getY());
	line->setEndX(end->getX());
	line->setEndY(end->getY());
	return line;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void LineEdit::update()
{
	start->setCoordinate(line->getStartX(), line->getStartY());
	end->setCoordinate(line->getEndX(), line->getEndY());
	QString text;
	text.sprintf("%1.4f", line->getDeltaX());
	deltaXDisplay->setText(text);
	text.sprintf("%1.4f", line->getDeltaY());
	deltaYDisplay->setText(text);
	text.sprintf("%1.4f", line->getLength());
	lengthDisplay->setText(text);
	text.sprintf("%1.4f", line->getAngle());
	angleDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void LineEdit::onStartChange(double &x, double &y)
{
	line->setStart(x, y);
	update();
}

void LineEdit::onStartSpecify()
{
	// TODO: onStartSpecify()
}

void LineEdit::onEndChange(double &x, double &y)
{
	line->setEnd(x, y);
	update();
}

void LineEdit::onEndSpecify()
{
	// TODO: onEndSpecify()
}

// EOF
