/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/edit/rayedit.cpp                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/edit/rayedit.h>

#include <qlabel.h>
#include <qmessagebox.h>
#include <concadgui/edit/coordinateedit.h>
#include <cad/engine/cadray.h>

using namespace concadgui::edit;
using cad::engine::CADRay;

/* TRANSLATOR concadgui::edit::RayEdit */

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

RayEdit::RayEdit(CADRay* ray, QWidget* parent, const char* name):
RayEditBase(parent, name)
{
	this->adjustSize();
	this->setFixedSize(width(), height());
	this->ray = ray;
	this->start->setTitle("First Point");
	this->second->setTitle("Second Point");
	
	connect(start, SIGNAL(changed(double&,double&)), this, 
		SLOT(onStartChange(double&,double&)));
	connect(start, SIGNAL(specifyPoint()), this, SLOT(onStartSpecify()));
	connect(second, SIGNAL(changed(double&,double&)), this, 
		SLOT(onSecondChange(double&,double&)));
	connect(second, SIGNAL(specifyPoint()), this, SLOT(onSecondSpecify()));
	
	update();
}

RayEdit::~RayEdit()
{
	
}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the edited entity */
CADEntity* RayEdit::getEntity() throw (Exception)
{
	ray->setStartX(start->getX());
	ray->setStartY(start->getY());
	ray->setSecondX(second->getX());
	ray->setSecondY(second->getY());
	return ray;
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void RayEdit::update()
{
	start->setCoordinate(ray->getStartX(), ray->getStartY());
	second->setCoordinate(ray->getSecondX(), ray->getSecondY());
	QString text;
	text.sprintf("%1.4f", ray->getDirectionX());
	directionXDisplay->setText(text);
	text.sprintf("%1.4f", ray->getDirectionY());
	directionYDisplay->setText(text);
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void RayEdit::onStartChange(double &x, double &y)
{
	ray->setStart(x, y);
	update();	
}

void RayEdit::onStartSpecify()
{

}

void RayEdit::onSecondChange(double &x, double &y)
{
	ray->setSecond(x, y);
	update();	
}

void RayEdit::onSecondSpecify()
{

}

// EOF
