/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/widgets/commandline.cpp                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/widgets/commandline.h>

#include <qmessagebox.h>
#include <qapplication.h>
#include <concadio/drawingmanager.h>
#include <concadio/iointerface.h>

using concadgui::widgets::CommandLine;
using namespace concadio;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CommandLine::CommandLine(IOInterface* io, QWidget* parent, char* name) : 
QLineEdit(parent, name)
{
	iointerface = io;
	QFont font("Courier", 12);
	setFont(font);
	setMinimumHeight(20);
	setMaximumHeight(minimumHeight());
	setReadOnly(true);
}

CommandLine::~CommandLine()
{
	
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void CommandLine::print(QString s)
{
	currentText += s;
	printAll();
}

void CommandLine::clear()
{
	currentText = "";
	currentInput = "";
	printAll();
}

/***************************************************************************
 * Protected Methods                                                       *
 ***************************************************************************/

void CommandLine::keyPressEvent(QKeyEvent* e)
{
	int key = e->key();
	QString line, input;
	
	switch (key)
	{
	case Qt::Key_Enter:
	case Qt::Key_Return:
		if ((iointerface->getIOState() == IO_Ready) && (currentInput == ""))
		{
			currentInput = iointerface->getCommandHistory()->last();
			printAll();
		}
		line = currentText + currentInput;
		input = currentInput;
		clear();
		emit this->input(line, input);
		break;
	case Qt::Key_Backspace:
		currentInput = currentInput.left(currentInput.length()-1);
		printAll();
		break;
	case Qt::Key_Up:
		currentInput = iointerface->getCommandHistory()->previous();
		printAll();
		break;
	case Qt::Key_Down:
		currentInput = iointerface->getCommandHistory()->next();
		printAll();
		break;
	case Qt::Key_Escape:
		emit escapePressed();
		break;
	default:
		char character = e->ascii();
		bool accept = false;
		if ((character >= 'a') && (character <= 'z'))
			accept = true;
		if ((character >= 'A') && (character <= 'Z'))
			accept = true;
		if ((character >= '0') && (character <= '9'))
			accept = true;
		switch (character)
		{
		case ',':
		case '.':
		case '+':
		case '-':
		case '<':
		case '>':
		case '@':
		case ' ':
		case '\'':
			accept = true;	
		}
		if (accept)
		{
			currentInput += e->ascii();
			printAll();
		}
		break;
	}
}

/***************************************************************************
 * Private Methods                                                         *
 ***************************************************************************/

void CommandLine::printAll()
{
	setText(currentText + currentInput);
}

// EOF
