/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/widgets/commandline.cpp                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/widgets/commandwidget.h>

#include <qtextedit.h>
#include <concadgui/widgets/commandline.h>
#include <concadio/drawingmanager.h>
#include <concadio/iointerface.h>

using concadgui::widgets::CommandLine;
using concadgui::widgets::CommandWidget;
using namespace concadio;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

CommandWidget::CommandWidget(IOInterface* io, Place p, QWidget * parent, const char * name, WFlags f): 
QDockWindow(p, parent, name,f)
{
	this->setFixedExtentHeight(70);
	this->setHorizontallyStretchable(true);
	this->setVerticallyStretchable(true);
	
	commandLine = new CommandLine(io, this);
	commandLine->setGeometry(0, height()-commandLine->height(), width(),
		commandLine->height());
	connect(commandLine, SIGNAL(input(QString&,QString&)), this,
		SLOT(appendLine(QString&,QString&)));
	connect(commandLine, SIGNAL(escapePressed()), this, SLOT(escape()));
	this->history = new QTextEdit(this);
	this->history->setGeometry(0, 0, width(), height()-commandLine->height());
	this->history->setFont(QFont("Courier", 12));
	this->history->setReadOnly(true);
}

CommandWidget::~CommandWidget()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

CommandLine* CommandWidget::getCommandLine()
{
	return commandLine;
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void CommandWidget::print(QString s)
{
	commandLine->print(s);
}

void CommandWidget::printLine(QString s)
{
	history->append(commandLine->text()+s);
	commandLine->clear();
}

/***************************************************************************
 * Protected Methods                                                       *
 ***************************************************************************/

void CommandWidget::resizeEvent(QResizeEvent* e)
{
	commandLine->setGeometry(0, height()-commandLine->height(), width(),
		commandLine->height());
	history->setGeometry(0, 0, width(), height()-commandLine->height());
}

/***************************************************************************
 * Private Slots                                                           *
 ***************************************************************************/

void CommandWidget::appendLine(QString& line, QString& input)
{
	history->append(line);
	emit this->input(input);
}

void CommandWidget::escape()
{
	emit escapePressed();
}

// EOF
