/***************************************************************************
 *                                                                         *
 *   src/concadgui/src/widgets/entityview.cpp                              *
 *   (C) 2004 by Bernhard Jantscher                                        *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadgui/widgets/entityview.h>
#include <cad/engine/cadentity.h>

#include <qlistbox.h>
#include <qvbox.h>
#include <qevent.h>
#include <qpushbutton.h>

using concadgui::widgets::EntityView;
using namespace cad::engine;


/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

EntityView::EntityView (Place p, QWidget * parent, const char * name, WFlags f) : 
						QDockWindow(p,parent,name,f) , 
						vbox(new QVBox(this)) ,
						listbox(new QListBox(vbox))
{
	this->container = container;
	vbox->setMargin(8);
	vbox->setSpacing(8);
	vbox->setGeometry(0,0,200,200);

	//QPushButton *btEdit = new QPushButton("Edit Entity",vbox);
	//connect(btEdit,SIGNAL(clicked()),this,SLOT(editEntity()));
	
	connect(listbox,SIGNAL(doubleClicked(QListBoxItem*)), this, SLOT(editEntity(QListBoxItem*)));
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/
	
void EntityView::refresh(CADEntityContainer *container) 
{
    if (NULL != container) 
    {
	this->container = container;
    	listbox->clear();
	for (int i=0; i<container->getSize(); i++)
    	{
		CADEntity* ce = container->getEntityAt(i);
		listbox->insertItem(ce->toString());
	}
    } else qDebug("EntityView::refresh() - container is NULL!");
}	

/***************************************************************************
 * Protected Methods                                                       *
 ***************************************************************************/

void EntityView::resizeEvent(QResizeEvent* t)
{
	vbox->setGeometry(0,0,width(),height());
}

void EntityView::editEntity(QListBoxItem *item)
{
//	qDebug("signal caught!");
	if (NULL != item)
	{
//		qDebug("reading string");
		QString str = item->text();
		
//		qDebug("string is: "+str+", trying to get ID from string");
		int theID = str.section(":",0,0).toULong();

//		qDebug("ID is: "+QString::number(theID)+", trying to create dialog by ID");
		PropertiesDialog p(container->getEntity(theID));

//		qDebug("executing Dialog");
		p.exec();
	} 
	else qDebug ("EntityView::editEntity() - item is NULL!");
	
}
//EOF
