/***************************************************************************
 *                                                                         *
 *   src/concadio/src/creators/ellipsecreator.cpp                           *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/creators/ellipsecreator.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>
#include <cad/engine/cadellipse.h>
#include <cad/engine/cadvector.h>

#include <qobject.h>
#include <vector>
#include <cmath>

using namespace concadio;
using namespace concadio::creators;
using namespace cad::engine;
using namespace std;

double EllipseCreator::lastRadius = 0.0;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
EllipseCreator::EllipseCreator(DrawingManager* dm) : EntityCreator(dm)
{

}

/** Destructor */
EllipseCreator::~EllipseCreator()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * Start the creation process
 */
void EllipseCreator::create(IOInterface* io)
{
	try
	{
		QString input;
		bool valid = false;
		input = readPointInput(io, QObject::tr("Specify center point for ellipse: "));
		CADVector center = CADVector::parseString(input);
		if (!center.isAbsolute())
			center = center + io->getLastPoint();
		io->setLastPoint(center);
		
		input = readPointInput(io, QObject::tr("Specify end point of major axis: "));
		CADVector majorAxisEnd = CADVector::parseString(input);
		if (!majorAxisEnd.isAbsolute())
			majorAxisEnd = majorAxisEnd + io->getLastPoint();
		io->setLastPoint(majorAxisEnd);
		CADVector majorAxis = majorAxisEnd - center;
	
		double minorAxisLength = 
			readValueInput(io, QObject::tr("Specify length of minor axis: "), center);
		
		// Create ellipse
		CADEllipse* ellipse = new CADEllipse(center, majorAxis, minorAxisLength/majorAxis.getLength(), 
		dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen());
		dm->getDrawing()->addEntity(ellipse);
		undoAction = new UndoNewEllipse(*ellipse);
		io->draw(dm->getDrawing());
	}
	catch (...)
	{
		return;
	}
}

/**
 * undo the last creation part
 */
void EllipseCreator::undo(IOInterface* io)
{

}

UndoAble* EllipseCreator::getUndoActions()
{
	return undoAction;
}

// EOF
