/***************************************************************************
 *                                                                         *
 *   src/concadio/src/creators/linecreator.cpp                             *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/creators/linecreator.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>
#include <cad/engine/cadline.h>
#include <cad/engine/cadvector.h>

#include <qobject.h>

#include <vector>

using namespace concadio;
using namespace concadio::creators;
using namespace cad::engine;
using namespace std;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
LineCreator::LineCreator(DrawingManager* dm) : EntityCreator(dm)
{
	undoAction = new UndoHistory();
}

/** Destructor */
LineCreator::~LineCreator()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * Start the creation process
 */
void LineCreator::create(IOInterface* io)
{
	vector<CADVector> pointList;
	bool finished = false;
	pointCount = 0;
	while (!finished)
	{
		QString input;
		CADVector point;
		try
		{
			QStringList options;
			if (pointCount == 0)
			{
				input = readPointInput(io, QObject::tr("Specify first point: "));
			}
			else if (pointCount == 1)
			{
				input = readPointInput(io, QObject::tr("Specify next point: "));
			}
			else if ((pointCount > 1) && (pointCount < 3))
			{
				options << "u";
				input = readPointOptionInput(io, QObject::tr("Specify next point or [Undo]: "), options);
			}
			else
			{
				options << "u" << "c";
				input = readPointOptionInput(io, QObject::tr("Specify next point or [Close/Undo]: "), options);
			}
		}
		catch (...)
		{
			return;
		}

		if ((pointCount > 1) && (input == "u"))
		{
			this->undo(io);
			//pointCount--;
			continue;
		}
		else if ((pointCount >= 3) && (input == "c"))
		{
			// Close line
			CADVector start = pointList.at(pointList.size()-1);
			CADVector end = pointList.at(0);
			CADLine* line = new CADLine(start, end, 
				dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen());
			dm->getDrawing()->addEntity(line);
			undoAction->addUndoAble(new UndoNewLine(*line));
			io->draw(dm->getDrawing());
			break;
		}
		else
		{
			point = CADVector::parseString(input);
			// Create line
			if (!point.isAbsolute())
				point = io->getLastPoint()+point;
			io->setLastPoint(point);
			pointList.push_back(point);
			if (pointCount > 0)
			{
				CADVector start = pointList.at(pointList.size()-2);
				CADVector end = pointList.at(pointList.size()-1);
				qDebug("start: "+QString::number(start.getX())+","+QString::number(start.getY()));
				qDebug("end: "+QString::number(end.getX())+","+QString::number(end.getY()));
				//CADLine* line = new CADLine(dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen(), start.getX(), start.getY(), end.getX(), end.getY());
				CADLine* line = new CADLine(start, end, dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen());
				qDebug("start: "+QString::number(line->getStartX())+","+QString::number(line->getStartY()));
				qDebug("end: "+QString::number(line->getEndX())+","+QString::number(line->getEndY()));
				dm->getDrawing()->addEntity(line);
				undoAction->addUndoAble(new UndoNewLine(*line));
			}
			pointCount++;
			io->draw(dm->getDrawing());
		}
	}
}

/**
 * undo the last creation part
 */
void LineCreator::undo(IOInterface* io)
{
	// TODO: concad crashes when getting all undo actions if some actions where undone during creation
	undoAction->undo(dm, io);
	pointCount--;
	io->draw(dm->getDrawing());
}

UndoAble* LineCreator::getUndoActions()
{
	if (undoAction == 0)
	{
		return 0;
	}
	return undoAction->toUndoGroup();
}

// EOF
