/***************************************************************************
 *                                                                         *
 *   src/concadio/src/creators/pointcreator.cpp                            *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/creators/pointcreator.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>
#include <cad/engine/cadpoint.h>
#include <cad/engine/cadvector.h>

#include <qobject.h>

using namespace concadio;
using namespace concadio::creators;
using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
PointCreator::PointCreator(DrawingManager* dm) : EntityCreator(dm)
{

}

/** Destructor */
PointCreator::~PointCreator()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * Start the creation process
 */
void PointCreator::create(IOInterface* io)
{
	QString input;
	try
	{
		input = readPointInput(io, QObject::tr("Specify point: "));
	}
	catch (...)
	{
		return;
	}
	CADVector point = CADVector::parseString(input);
	if (!point.isAbsolute())	point = io->getLastPoint()+point;
	io->setLastPoint(point);
	// Create point
	CADPoint* entity = new CADPoint(point, dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen());
	dm->getDrawing()->addEntity(entity);
	undoAction = new UndoNewPoint(*entity);

	io->draw(dm->getDrawing());
}

/**
 * undo the last creation part
 */
void PointCreator::undo(IOInterface* io)
{

}

UndoAble* PointCreator::getUndoActions()
{
	return undoAction;
}

// EOF
