/***************************************************************************
 *                                                                         *
 *   src/concadio/src/creators/raycreator.cpp                              *
 *   (C) 2005 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/creators/raycreator.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>
#include <cad/engine/cadvector.h>

#include <qobject.h>

#include <vector>

using namespace concadio;
using namespace concadio::creators;
using namespace cad::engine;
using namespace std;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
RayCreator::RayCreator(DrawingManager* dm) : EntityCreator(dm)
{

}

/** Destructor */
RayCreator::~RayCreator()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * Start the creation process
 */
void RayCreator::create(IOInterface* io)
{
	try
	{
		undoAction = new UndoAbleGroup;
		QString input;
		input = readPointInput(io, QObject::tr("Specify a point: "));
		CADVector first = CADVector::parseString(input);
		if (!first.isAbsolute()) first = first + io->getLastPoint();
		io->setLastPoint(first);
		
		for (;;)
		{
			input = readPointInput(io, QObject::tr("Through point: "));
			CADVector point = CADVector::parseString(input);
			if (!point.isAbsolute()) point = point + io->getLastPoint();
			io->setLastPoint(point);
			// Create Ray
			CADRay* ray = new CADRay(first, point, 
				dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen());
			dm->getDrawing()->addEntity(ray);
			undoAction->addUndoAble(new UndoNewRay(*ray));
			io->draw(dm->getDrawing());
		}
	}
	catch (...)
	{
		return;
	}
}

/**
 * undo the last creation part
 */
void RayCreator::undo(IOInterface* io)
{

}

UndoAble* RayCreator::getUndoActions()
{
	return undoAction;
}

// EOF
