/***************************************************************************
 *                                                                         *
 *   src/concadio/src/creators/xlinecreator.cpp                            *
 *   (C) 2005 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/creators/xlinecreator.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>
#include <cad/engine/cadvector.h>

#include <qobject.h>

#include <vector>
#include <cmath>

using namespace concadio;
using namespace concadio::creators;
using namespace cad::engine;
using namespace std;

double XLineCreator::lastAngle = 0.0;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
XLineCreator::XLineCreator(DrawingManager* dm) : EntityCreator(dm)
{

}

/** Destructor */
XLineCreator::~XLineCreator()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

/**
 * Start the creation process
 */
void XLineCreator::create(IOInterface* io)
{
	try
	{
		undoAction = new UndoAbleGroup;
		QString input;
		CADVector point;
		char mode = 'p';
		double angle;
		QStringList options;
		options << "h" << "v" << "a";
		input = readPointOptionInput(io, QObject::tr("Specify a point or [Hor/Ver/Ang]: "), options);
		if (input == "h")
			mode = 'h';
		else if (input == "v")
			mode = 'v';
		else if (input == "a") 
			mode = 'a';
		else
		{
			point = CADVector::parseString(input);
			if (!point.isAbsolute())
				point = point + io->getLastPoint();
			io->setLastPoint(point);
		}
		
		switch (mode)
		{
		case 'h':
			angle = 0.0;
			break;
		case 'v':
			angle = 90.0;
			break;
		case 'a':
			angle = readAngleInput(io, QObject::tr("Specify angle of xline")+" ("+QString().sprintf("%1.4f", lastAngle)+"): ", QString::number(lastAngle));
			lastAngle = angle;
			break;
		}
		
		for (;;)
		{
			input = readPointInput(io, QObject::tr("Through point: "));
			CADVector point2;
			point2 = CADVector::parseString(input);
			if (!point2.isAbsolute()) point2 = point2 + io->getLastPoint();
			io->setLastPoint(point2);
			// Create XLine
			if (mode != 'p')
			{
				point = point2;
				point2.setPolar(1, angle);
				point2 = point2 + point;
			}
			CADXLine* xline = new CADXLine(point, point2, 
				dm->getDrawing()->getActiveLayer().getName(), dm->getDrawing()->getActivePen());
			dm->getDrawing()->addEntity(xline);
			undoAction->addUndoAble(new UndoNewXLine(*xline));
			io->draw(dm->getDrawing());
		}
	}
	catch (...)
	{
		return;
	}
}

/**
 * undo the last creation part
 */
void XLineCreator::undo(IOInterface* io)
{

}

UndoAble* XLineCreator::getUndoActions()
{
	return undoAction;
}

// EOF
