/***************************************************************************
 *                                                                         *
 *   src/concadio/src/iointerface.cpp                                      *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/iointerface.h>

#include <concadio/drawingmanager.h>
#include <concadio/commandhistory.h>
#include <cad/engine/caddrawing.h>

#include <qwidget.h>

using namespace concadio;
using namespace cad::engine;

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
IOInterface::IOInterface()
{
	this->drawingManager = DrawingManager::getInstance();
	commandHistory = new CommandHistory;
	locked = false;
}

/** Destructor */
IOInterface::~IOInterface()
{

}

/***************************************************************************
 * Get/Set Methods                                                         *
 ***************************************************************************/

/** @return the drawing manager */
DrawingManager* IOInterface::getDrawingManager() const
{
	return drawingManager;
}

/** @return the command history */
CommandHistory* IOInterface::getCommandHistory() const
{
	return commandHistory;
}

/** @return the IO state */
IOState IOInterface::getIOState() const
{
	return state;
}

/** set the IO state */
void IOInterface::setIOState(IOState state)
{
	this->state = state;
	switch (state)
	{
	case IO_Ready:
		print("Command: ");
		break;
	case IO_Cancelled:
		break;
	case IO_Input:
		break;
	case IO_Finished:
		break;
	}
}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void IOInterface::runCommand(QString command)
{
	command = command.upper();
	if (command == QObject::tr("NEW")) drawingManager->fileNew(this);
	else if (command == QObject::tr("OPEN")) drawingManager->fileOpen(this);
	else if (command == QObject::tr("SAVE")) drawingManager->fileSave(this);
	else if (command == QObject::tr("SAVEAS")) drawingManager->fileSaveAs(this);
	else if (command == QObject::tr("PLOT")) drawingManager->filePlot(this);
	else if (command == QObject::tr("QUIT")) quitApplication();
	else if (command == QObject::tr("UNDO")) drawingManager->editUndo(this);
	else if (command == QObject::tr("REDO")) drawingManager->editRedo(this);
	else if ((command == QObject::tr("LAYER")) || (command == QObject::tr("LA"))) drawingManager->propertiesLayer(this);
	else if (command == QObject::tr("DDCOLOR")) drawingManager->propertiesColor(this);
	else if (command == QObject::tr("DDEMODES")) drawingManager->propertiesObject(this);
	else if (command == QObject::tr("DDLTYPE")) drawingManager->propertiesLinetype(this);
	else if ((command == QObject::tr("LINE")) || (command == QObject::tr("L"))) drawingManager->drawLine(this);
	else if (command == QObject::tr("XLINE")) drawingManager->drawXLine(this);
	else if (command == QObject::tr("RAY")) drawingManager->drawRay(this);
	else if (command == QObject::tr("PLINE")) drawingManager->drawPLine(this);
	else if ((command == QObject::tr("ARC")) || (command == QObject::tr("A"))) drawingManager->drawArc(this);
	else if ((command == QObject::tr("CIRCLE")) || (command == QObject::tr("C"))) drawingManager->drawCircle(this);
	else if (command == QObject::tr("DONUT")) drawingManager->drawRing(this);
	else if (command == QObject::tr("ELLIPSE")) drawingManager->drawEllipse(this);
	else if (command == QObject::tr("POLYGON")) drawingManager->drawPolygon(this);
	else if ((command == QObject::tr("RECTANG")) || (command == QObject::tr("REC"))) drawingManager->drawRectangle(this);
	else if (command == QObject::tr("SOLID")) drawingManager->drawSolid(this);
	else if (command == QObject::tr("POINT")) drawingManager->drawPoint(this);
	else if (command == QObject::tr("BLOCK")) drawingManager->drawBlock(this);
	else if ((command == QObject::tr("INSERT")) || (command == QObject::tr("DDINSERT"))) drawingManager->drawBlockInsert(this);
	else if (command == QObject::tr("HATCH")) drawingManager->drawHatch(this);
	else if (command == QObject::tr("MTEXT")) drawingManager->drawText(this);
	else if (command == QObject::tr("TEXT")) drawingManager->drawTextSL(this);
	else if ((command == QObject::tr("MOVE")) || (command == QObject::tr("M"))) drawingManager->modifyMove(this);
	else if ((command == QObject::tr("COPY")) || (command == QObject::tr("CP"))) drawingManager->modifyCopy(this);
	else if (command == QObject::tr("OFFSET")) drawingManager->modifyOffset(this);
	else if (command == QObject::tr("MIRROR")) drawingManager->modifyMirror(this);
	else if (command == QObject::tr("ARRAY")) drawingManager->modifyArrayRect(this);
	else if (command == QObject::tr("ROTATE")) drawingManager->modifyRotate(this);
	else if (command == QObject::tr("STRETCH")) drawingManager->modifyStretch(this);
	else if (command == QObject::tr("SCALE")) drawingManager->modifyScale(this);
	else if (command == QObject::tr("LENGTHEN")) drawingManager->modifyLengthen(this);
	else if (command == QObject::tr("TRIM")) drawingManager->modifyTrim(this);
	else if (command == QObject::tr("EXTEND")) drawingManager->modifyExtend(this);
	else if (command == QObject::tr("BREAK")) drawingManager->modifyBreak(this);
	else if (command == QObject::tr("DDEDIT")) drawingManager->modifyEditText(this);
	else if (command == QObject::tr("HATCHEDIT")) drawingManager->modifyHatchEdit(this);
	else if (command == QObject::tr("CHAMFER")) drawingManager->modifyChamfer(this);
	else if (command == QObject::tr("FILLET")) drawingManager->modifyFillet(this);
	else if (command == QObject::tr("EXPLODE")) drawingManager->modifyExplode(this);
	else if ((command == QObject::tr("ERASE")) || (command == QObject::tr("E"))) drawingManager->modifyErase(this);
	else printLine(QObject::tr("Command not found."));
	commandHistory->add(command);
}

// EOF
