/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undo.cpp                                    *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undo.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>

using namespace concadio;
using namespace concadio::undoredo;

/***************************************************************************
 * UndoAbleGroup                                                           *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
UndoAbleGroup::UndoAbleGroup()
{

}

/** Copy-Constructor */
UndoAbleGroup::UndoAbleGroup(UndoAbleGroup& undoAbleGroup) : UndoAble()
{
	QValueList<UndoAble*>::iterator i;
	for (i = undoAbleGroup.undoGroup.begin(); i != undoAbleGroup.undoGroup.begin(); i++)
		this->addUndoAble((*i)->copy());
}

/** Destructor */
UndoAbleGroup::~UndoAbleGroup()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoAbleGroup::copy()
{
	return new UndoAbleGroup(*this);
}

void UndoAbleGroup::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		for (int i = undoGroup.size()-1; i>=0; i--)
		{
			undoGroup[i]->undo(dm, io);
		}
		undone = true;
	}
}

void UndoAbleGroup::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		for (int i = 0; i<undoGroup.size(); i++)
			undoGroup[i]->redo(dm, io);
		undone = false;
	}
}

/**
 * add an undoable object to the group
 */
void UndoAbleGroup::addUndoAble(UndoAble* undoable)
{
	undoGroup.push_back(undoable);
}

/***************************************************************************
 * UndoHistory                                                             *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

/** Constructor */
UndoHistory::UndoHistory()
{

}

/** Destructor */
UndoHistory::~UndoHistory()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

void UndoHistory::undo(DrawingManager* dm, IOInterface* io)
{
	if (undoGroup.size() > 0)
	{
		UndoAble* undoable = undoGroup.back();
		undoGroup.pop_back();
		undoable->undo(dm, io);
		redoGroup.push_back(undoable);
	}
}

void UndoHistory::redo(DrawingManager* dm, IOInterface* io)
{
	if (redoGroup.size() > 0)
	{
		UndoAble* undoable = redoGroup.back();
		redoGroup.pop_back();
		undoable->redo(dm, io);
		undoGroup.push_back(undoable);
	}
}

/** add an undoable to the history */
void UndoHistory::addUndoAble(UndoAble* undoable)
{
	undoGroup.push_back(undoable);
	while (!redoGroup.empty())
	{
		UndoAble* undoable = redoGroup.back();
		redoGroup.pop_back();
		delete undoable;
	}
}

/** clear the undo history */
void UndoHistory::clear()
{
	UndoAble* undoable;
	while (!undoGroup.empty())
	{
		undoable = undoGroup.back();
		undoGroup.pop_back();
		delete undoable;
	}
	while (!redoGroup.empty())
	{
		undoable = redoGroup.back();
		redoGroup.pop_back();
		delete undoable;
	}
}

/** convert the UndoHistory to an UndoGroup */
UndoAbleGroup* UndoHistory::toUndoGroup()
{
	UndoAbleGroup* undoAbleGroup = new UndoAbleGroup;
	for (int i = 0; i<undoGroup.size(); i++)
	{
		undoAbleGroup->addUndoAble(undoGroup[i]->copy());
	}
	while (!undoGroup.empty()) undoGroup.pop_back();
	return undoAbleGroup;
}

// EOF
