/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undoarc.cpp                                 *
 *   (C) 2005 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undoarc.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using cad::engine::CADArc;

/***************************************************************************
 * UndoNewArc                                                              *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewArc::UndoNewArc(CADArc arc) : arc(arc)
{

}

UndoNewArc::~UndoNewArc()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewArc::copy()
{
	return new UndoNewArc(*this);
}

void UndoNewArc::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->removeEntity(arc.getEntityID());
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoNewArc::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->addEntity(new CADArc(arc));
		io->draw(dm->getDrawing());
		undone = false;
	}
}

/***************************************************************************
 * UndoDeleteArc                                                           *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoDeleteArc::UndoDeleteArc(CADArc arc) : arc(arc)
{

}

UndoDeleteArc::~UndoDeleteArc()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoDeleteArc::copy()
{
	return new UndoDeleteArc(*this);
}

void UndoDeleteArc::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->addEntity(new CADArc(arc));
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoDeleteArc::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->removeEntity(arc.getEntityID());
		io->draw(dm->getDrawing());
		undone = false;
	}
}

// EOF
