/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undoellipse.cpp                             *
 *   (C) 2005 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undoellipse.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using cad::engine::CADEllipse;

/***************************************************************************
 * UndoNewEllipse                                                             *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewEllipse::UndoNewEllipse(CADEllipse ellipse) : ellipse(ellipse)
{

}

UndoNewEllipse::~UndoNewEllipse()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewEllipse::copy()
{
	return new UndoNewEllipse(*this);
}

void UndoNewEllipse::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->removeEntity(ellipse.getEntityID());
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoNewEllipse::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->addEntity(new CADEllipse(ellipse));
		io->draw(dm->getDrawing());
		undone = false;
	}
}

/***************************************************************************
 * UndoDeleteEllipse                                                          *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoDeleteEllipse::UndoDeleteEllipse(CADEllipse ellipse) : ellipse(ellipse)
{

}

UndoDeleteEllipse::~UndoDeleteEllipse()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoDeleteEllipse::copy()
{
	return new UndoDeleteEllipse(*this);
}

void UndoDeleteEllipse::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->addEntity(new CADEllipse(ellipse));
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoDeleteEllipse::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->removeEntity(ellipse.getEntityID());
		io->draw(dm->getDrawing());
		undone = false;
	}
}

// EOF
