/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undolayer.cpp                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undolayer.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using namespace cad::engine;

/***************************************************************************
 * UndoActiveLayer                                                         *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoActiveLayer::UndoActiveLayer(QString oldLayer, QString newLayer)
{
	this->oldLayer = oldLayer;
	this->newLayer = newLayer;
}

UndoActiveLayer::~UndoActiveLayer()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoActiveLayer::copy()
{
	return new UndoActiveLayer(*this);
}

void UndoActiveLayer::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->setActiveLayer(oldLayer);
		io->updatePropertiesDisplay();
		undone = true;
	}
}

void UndoActiveLayer::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->setActiveLayer(newLayer);
		io->updatePropertiesDisplay();
		undone = false;
	}
}

/***************************************************************************
 * UndoNewLayer                                                            *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewLayer::UndoNewLayer(CADLayer layer) : layer(layer)
{

}

UndoNewLayer::~UndoNewLayer()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewLayer::copy()
{
	return new UndoNewLayer(*this);
}

void UndoNewLayer::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		CADLayerList layerList = dm->getDrawing()->getLayerList();
		layerList.remove(layer.getName());
		dm->getDrawing()->updateLayerList(layerList, LayerRenamingManager());
		io->updatePropertiesDisplay();
		undone = true;
	}
}

void UndoNewLayer::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		CADLayerList layerList = dm->getDrawing()->getLayerList();
		layerList.add(layer);
		dm->getDrawing()->updateLayerList(layerList, LayerRenamingManager());
		io->updatePropertiesDisplay();
		undone = false;
	}
}

/***************************************************************************
 * UndoChangeLayer                                                         *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoChangeLayer::UndoChangeLayer(CADLayer oldLayer, CADLayer newLayer) :
oldLayer(oldLayer), newLayer(newLayer)
{

}

UndoChangeLayer::~UndoChangeLayer()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoChangeLayer::copy()
{
	return new UndoChangeLayer(*this);
}

void UndoChangeLayer::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		CADLayerList layerList = dm->getDrawing()->getLayerList();
		layerList.update(newLayer.getName(), oldLayer);
		LayerRenamingManager rm;
		if (oldLayer.getName() != newLayer.getName())
			rm.add(newLayer.getName(), oldLayer.getName());
		dm->getDrawing()->updateLayerList(layerList, rm);
		io->updatePropertiesDisplay();
		undone = true;
	}
}

void UndoChangeLayer::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		CADLayerList layerList = dm->getDrawing()->getLayerList();
		layerList.update(oldLayer.getName(), newLayer);
		LayerRenamingManager rm;
		if (oldLayer.getName() != newLayer.getName())
			rm.add(oldLayer.getName(), newLayer.getName());
		dm->getDrawing()->updateLayerList(layerList, rm);
		io->updatePropertiesDisplay();
		undone = false;
	}
}

/***************************************************************************
 * UndoDeleteLayer                                                         *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoDeleteLayer::UndoDeleteLayer(CADLayer layer) : layer(layer)
{

}

UndoDeleteLayer::~UndoDeleteLayer()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoDeleteLayer::copy()
{
	return new UndoDeleteLayer(*this);
}

void UndoDeleteLayer::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		CADLayerList layerList = dm->getDrawing()->getLayerList();
		layerList.add(layer);
		dm->getDrawing()->updateLayerList(layerList, LayerRenamingManager());
		io->updatePropertiesDisplay();
		undone = true;
	}
}

void UndoDeleteLayer::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		CADLayerList layerList = dm->getDrawing()->getLayerList();
		layerList.remove(layer.getName());
		dm->getDrawing()->updateLayerList(layerList, LayerRenamingManager());
		io->updatePropertiesDisplay();
		undone = false;
	}
}

// EOF
