/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undoline.cpp                                *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undoline.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using cad::engine::CADLine;

/***************************************************************************
 * UndoNewLine                                                             *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewLine::UndoNewLine(CADLine line) : line(line)
{

}

UndoNewLine::~UndoNewLine()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewLine::copy()
{
	return new UndoNewLine(*this);
}

void UndoNewLine::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->removeEntity(line.getEntityID());
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoNewLine::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->addEntity(new CADLine(line));
		io->draw(dm->getDrawing());
		undone = false;
	}
}

/***************************************************************************
 * UndoDeleteLine                                                          *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoDeleteLine::UndoDeleteLine(CADLine line) : line(line)
{

}

UndoDeleteLine::~UndoDeleteLine()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoDeleteLine::copy()
{
	return new UndoDeleteLine(*this);
}

void UndoDeleteLine::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->addEntity(new CADLine(line));
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoDeleteLine::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->removeEntity(line.getEntityID());
		io->draw(dm->getDrawing());
		undone = false;
	}
}

// EOF
