/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undolinetype.cpp                            *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undolinetype.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using namespace cad::engine;

/***************************************************************************
 * UndoNewLinetype                                                         *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewLinetype::UndoNewLinetype(CADLinetype linetype)
{
	this->linetype = linetype;
}

UndoNewLinetype::~UndoNewLinetype()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewLinetype::copy()
{
	return new UndoNewLinetype(*this);
}

void UndoNewLinetype::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		CADLinetypeList linetypeList = dm->getDrawing()->getLinetypeList();
		linetypeList.remove(linetype.getName());
		dm->getDrawing()->updateLinetypeList(linetypeList);
		io->updatePropertiesDisplay();
		undone = true;
	}
}

void UndoNewLinetype::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		CADLinetypeList linetypeList = dm->getDrawing()->getLinetypeList();
		linetypeList.add(linetype, true);
		dm->getDrawing()->updateLinetypeList(linetypeList);
		io->updatePropertiesDisplay();
		undone = false;
	}
}

/***************************************************************************
 * UndoChangeLinetype                                                      *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoChangeLinetype::UndoChangeLinetype(CADLinetype oldLinetype, 
CADLinetype newLinetype)
{
	this->oldLinetype = oldLinetype;
	this->newLinetype = newLinetype;
}

UndoChangeLinetype::~UndoChangeLinetype()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoChangeLinetype::copy()
{
	return new UndoChangeLinetype(*this);
}

void UndoChangeLinetype::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		CADLinetypeList linetypeList = dm->getDrawing()->getLinetypeList();
		linetypeList.add(oldLinetype, true);
		dm->getDrawing()->updateLinetypeList(linetypeList);
		io->updatePropertiesDisplay();
		undone = true;
	}
}

void UndoChangeLinetype::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		CADLinetypeList linetypeList = dm->getDrawing()->getLinetypeList();
		linetypeList.add(newLinetype, true);
		dm->getDrawing()->updateLinetypeList(linetypeList);
		io->updatePropertiesDisplay();
		undone = false;
	}
}

// EOF
