/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undopoint.cpp                               *
 *   (C) 2004 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undopoint.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using cad::engine::CADPoint;

/***************************************************************************
 * UndoNewPoint                                                            *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewPoint::UndoNewPoint(CADPoint point) : point(point)
{

}

UndoNewPoint::~UndoNewPoint()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewPoint::copy()
{
	return new UndoNewPoint(*this);
}

void UndoNewPoint::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->removeEntity(point.getEntityID());
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoNewPoint::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->addEntity(new CADPoint(point));
		io->draw(dm->getDrawing());
		undone = false;
	}
}

/***************************************************************************
 * UndoDeletePoint                                                         *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoDeletePoint::UndoDeletePoint(CADPoint point) : point(point)
{

}

UndoDeletePoint::~UndoDeletePoint()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoDeletePoint::copy()
{
	return new UndoDeletePoint(*this);
}

void UndoDeletePoint::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->addEntity(new CADPoint(point));
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoDeletePoint::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->removeEntity(point.getEntityID());
		io->draw(dm->getDrawing());
		undone = false;
	}
}

// EOF
