/***************************************************************************
 *                                                                         *
 *   src/concadio/src/undoredo/undoray.cpp                                 *
 *   (C) 2005 by Christoph Permes                                          *
 *   ConstructCAD Project                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <concadio/undoredo/undoray.h>

#include <concadio/iointerface.h>
#include <concadio/drawingmanager.h>
#include <cad/engine/caddrawing.h>

using namespace concadio;
using namespace concadio::undoredo;
using cad::engine::CADRay;

/***************************************************************************
 * UndoNewRay                                                              *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoNewRay::UndoNewRay(CADRay ray) : ray(ray)
{

}

UndoNewRay::~UndoNewRay()
{

}

/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoNewRay::copy()
{
	return new UndoNewRay(*this);
}

void UndoNewRay::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->removeEntity(ray.getEntityID());
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoNewRay::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->addEntity(new CADRay(ray));
		io->draw(dm->getDrawing());
		undone = false;
	}
}

/***************************************************************************
 * UndoDeleteRay                                                           *
 ***************************************************************************/

/***************************************************************************
 * Construction/Destruction                                                *
 ***************************************************************************/

UndoDeleteRay::UndoDeleteRay(CADRay ray) : ray(ray)
{

}

UndoDeleteRay::~UndoDeleteRay()
{

}


/***************************************************************************
 * Public Methods                                                          *
 ***************************************************************************/

UndoAble* UndoDeleteRay::copy()
{
	return new UndoDeleteRay(*this);
}

void UndoDeleteRay::undo(DrawingManager* dm, IOInterface* io)
{
	if (!undone)
	{
		dm->getDrawing()->addEntity(new CADRay(ray));
		io->draw(dm->getDrawing());
		undone = true;
	}
}

void UndoDeleteRay::redo(DrawingManager* dm, IOInterface* io)
{
	if (undone)
	{
		dm->getDrawing()->removeEntity(ray.getEntityID());
		io->draw(dm->getDrawing());
		undone = false;
	}
}

// EOF
